@@ -1,8 +1,5 @@
 <?php
-
-/* $Id: blowfish.php,v 2.4 2004/12/16 18:26:43 lem9 Exp $ */
-// vim: expandtab sw=4 ts=4 sts=4:
-
+/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * The Cipher_blowfish:: class implements the Cipher interface enryption data
  * using the Blowfish algorithm.
@@ -15,15 +12,15 @@
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Mike Cochrane <mike@graftonhall.co.nz>
- * @version $Revision: 2.4 $
+ * @version $Id: blowfish.php 11081 2008-01-25 09:35:48Z cybot_tm $
  * @since   Horde 2.2
  * @package horde.cipher
  */
 
 // Change for phpMyAdmin by lem9:
 //class Horde_Cipher_blowfish extends Horde_Cipher {
-class Horde_Cipher_blowfish {
-
+class Horde_Cipher_blowfish
+{
     /* Pi Array */
     var $p = array(
             0x243F6A88, 0x85A308D3, 0x13198A2E, 0x03707344,
@@ -297,18 +294,12 @@ class Horde_Cipher_blowfish {
     /* The number of rounds to do */
     var $_rounds = 16;
 
-    /* Constructor */
-    function Cipher_blowfish($params = null)
-    {
-    }
-
     /**
      * Set the key to be used for en/decryption
      *
      * @param String $key   The key to use
      */
-    function setKey($key)
-    {
+    function setKey($key) {
         $key = $this->_formatKey($key);
         $keyPos = $keyXor = 0;
 
@@ -326,61 +317,50 @@ class Horde_Cipher_blowfish {
 
         $encZero = array('L' => 0, 'R' => 0);
         for ($i = 0; $i + 1 < $iMax; $i += 2) {
-          $encZero = $this->_encryptBlock($encZero['L'], $encZero['R']);
-          $this->p[$i] = $encZero['L'];
-          $this->p[$i + 1] = $encZero['R'];
+            $encZero = $this->_encryptBlock($encZero['L'], $encZero['R']);
+            $this->p[$i] = $encZero['L'];
+            $this->p[$i + 1] = $encZero['R'];
         }
 
         $iMax = count($this->s1);
         for ($i = 0; $i < $iMax; $i += 2) {
-          $encZero = $this->_encryptBlock($encZero['L'], $encZero['R']);
-          $this->s1[$i] = $encZero['L'];
-          $this->s1[$i + 1] = $encZero['R'];
+            $encZero = $this->_encryptBlock($encZero['L'], $encZero['R']);
+            $this->s1[$i] = $encZero['L'];
+            $this->s1[$i + 1] = $encZero['R'];
         }
 
         $iMax = count($this->s2);
         for ($i = 0; $i < $iMax; $i += 2) {
-          $encZero = $this->_encryptBlock($encZero['L'], $encZero['R']);
-          $this->s2[$i] = $encZero['L'];
-          $this->s2[$i + 1] = $encZero['R'];
+            $encZero = $this->_encryptBlock($encZero['L'], $encZero['R']);
+            $this->s2[$i] = $encZero['L'];
+            $this->s2[$i + 1] = $encZero['R'];
         }
 
         $iMax = count($this->s3);
         for ($i = 0; $i < $iMax; $i += 2) {
-          $encZero = $this->_encryptBlock($encZero['L'], $encZero['R']);
-          $this->s3[$i] = $encZero['L'];
-          $this->s3[$i + 1] = $encZero['R'];
+            $encZero = $this->_encryptBlock($encZero['L'], $encZero['R']);
+            $this->s3[$i] = $encZero['L'];
+            $this->s3[$i + 1] = $encZero['R'];
         }
 
         $iMax = count($this->s4);
         for ($i = 0; $i < $iMax; $i += 2) {
-          $encZero = $this->_encryptBlock($encZero['L'], $encZero['R']);
-          $this->s4[$i] = $encZero['L'];
-          $this->s4[$i + 1] = $encZero['R'];
+            $encZero = $this->_encryptBlock($encZero['L'], $encZero['R']);
+            $this->s4[$i] = $encZero['L'];
+            $this->s4[$i + 1] = $encZero['R'];
         }
 
     }
 
-    /**
-     * Return the size of the blocks that this cipher needs
-     *
-     * @return Integer  The number of characters per block
-     */
-    function getBlockSize()
-    {
-        return 8;
-    }
-
     /**
      * Encrypt a block on data.
      *
      * @param String $block         The data to encrypt
-     * @param optional String $key  The key to use
+     * @param String $key  optional The key to use
      *
      * @return String the encrypted output
      */
-    function encryptBlock($block, $key = null)
-    {
+    function encryptBlock($block, $key = null) {
         if (!is_null($key)) {
             $this->setKey($key);
         }
@@ -389,7 +369,7 @@ class Horde_Cipher_blowfish {
         $parts = $this->_encryptBlock($L, $R);
         return pack("NN", $parts['L'], $parts['R']);
     }
-    
+
     /**
      * Encrypt a block on data.
      *
@@ -398,8 +378,7 @@ class Horde_Cipher_blowfish {
      *
      * @return String  The encrypted output.
      */
-    function _encryptBlock($L, $R)
-    {
+    function _encryptBlock($L, $R) {
         $L ^= $this->p[0];
         $R ^= ((($this->s1[($L >> 24) & 0xFF] + $this->s2[($L >> 16) & 0x0ff]) ^ $this->s3[($L >> 8) & 0x0ff]) + $this->s4[$L & 0x0ff]) ^ $this->p[1];
         $L ^= ((($this->s1[($R >> 24) & 0xFF] + $this->s2[($R >> 16) & 0x0ff]) ^ $this->s3[($R >> 8) & 0x0ff]) + $this->s4[$R & 0x0ff]) ^ $this->p[2];
@@ -425,29 +404,28 @@ class Horde_Cipher_blowfish {
     /**
      * Decrypt a block on data.
      *
-     * @param String $block         The data to decrypt
-     * @param optional String $key  The key to use
+     * @param String $block          The data to decrypt
+     * @param String $key   optional The key to use
      *
      * @return String the decrypted output
      */
-    function decryptBlock($block, $key = null)
-    {
+    function decryptBlock($block, $key = null) {
         if (!is_null($key)) {
             $this->setKey($key);
         }
 
-// change for phpMyAdmin
+        // change for phpMyAdmin
         $L = null;
         $R = null;
 
         $retarray = array_values(unpack('N*', $block));
-        if(isset($retarray[0])) {
+        if (isset($retarray[0])) {
             $L = $retarray[0];
         }
-        if(isset($retarray[1])) {
+        if (isset($retarray[1])) {
             $R = $retarray[1];
         }
-// end change for phpMyAdmin
+        // end change for phpMyAdmin
 
         $L ^= $this->p[17];
         $R ^= ((($this->s1[($L >> 24) & 0xFF] + $this->s2[($L >> 16) & 0x0ff]) ^ $this->s3[($L >> 8) & 0x0ff]) + $this->s4[$L & 0x0ff]) ^ $this->p[16];
@@ -474,53 +452,21 @@ class Horde_Cipher_blowfish {
     /**
      * Converts a text key into an array.
      *
+     * @param string $key
      * @return array  The key.
      */
-    function _formatKey($key)
-    {
+    function _formatKey($key) {
         return array_values(unpack('C*', $key));
     }
 
 }
 
 // higher-level functions:
-
-/**
- * String padding
- *
- * @param   string  input string
- * @param   integer length of the result
- * @param   string  the filling string
- * @param   integer padding mode
- *
- * @return  string  the padded string
- *
- * @access  public
- */
-function full_str_pad($input, $pad_length, $pad_string = '', $pad_type = 0) {
-    $str = '';
-    $length = $pad_length - strlen($input);
-    if ($length > 0) { // str_repeat doesn't like negatives
-        if ($pad_type == STR_PAD_RIGHT) { // STR_PAD_RIGHT == 1
-            $str = $input.str_repeat($pad_string, $length);
-        } elseif ($pad_type == STR_PAD_BOTH) { // STR_PAD_BOTH == 2
-            $str = str_repeat($pad_string, floor($length/2));
-            $str .= $input;
-            $str .= str_repeat($pad_string, ceil($length/2));
-        } else { // defaults to STR_PAD_LEFT == 0
-            $str = str_repeat($pad_string, $length).$input;
-        }
-    } else { // if $length is negative or zero we don't need to do anything
-        $str = $input;
-    }
-    return $str;
-}
-
 /**
  * Encryption using blowfish algorithm
  *
- * @param   string  original data
- * @param   string  the secret
+ * @param   string  $data   original data
+ * @param   string  $secret the secret
  *
  * @return  string  the encrypted result
  *
@@ -531,12 +477,16 @@ function full_str_pad($input, $pad_length, $pad_string = '', $pad_type = 0) {
 function PMA_blowfish_encrypt($data, $secret) {
     $pma_cipher = new Horde_Cipher_blowfish;
     $encrypt = '';
-    for ($i=0; $i<strlen($data); $i+=8) {
-        $block = substr($data, $i, 8);
-        if (strlen($block) < 8) {
-            $block = full_str_pad($block,8,"\0", 1);
-        }
-        $encrypt .= $pma_cipher->encryptBlock($block, $secret);
+
+    $data .= '_'; // triming fixed for DokuWiki FS#1690 FS#1713
+    $mod = strlen($data) % 8;
+
+    if ($mod > 0) {
+        $data .= str_repeat("\0", 8 - $mod);
+    }
+
+    foreach (str_split($data, 8) as $chunk) {
+        $encrypt .= $pma_cipher->encryptBlock($chunk, $secret);
     }
     return base64_encode($encrypt);
 }
@@ -544,8 +494,8 @@ function PMA_blowfish_encrypt($data, $secret) {
 /**
  * Decryption using blowfish algorithm
  *
- * @param   string  encrypted data
- * @param   string  the secret
+ * @param   string  $encdata encrypted data
+ * @param   string  $secret  the secret
  *
  * @return  string  original data
  *
@@ -557,11 +507,9 @@ function PMA_blowfish_decrypt($encdata, $secret) {
     $pma_cipher = new Horde_Cipher_blowfish;
     $decrypt = '';
     $data = base64_decode($encdata);
-    for ($i=0; $i<strlen($data); $i+=8) {
-        $decrypt .= $pma_cipher->decryptBlock(substr($data, $i, 8), $secret);
+
+    foreach (str_split($data, 8) as $chunk) {
+        $decrypt .= $pma_cipher->decryptBlock($chunk, $secret);
     }
-    return trim($decrypt);
+    return substr(rtrim($decrypt, "\0"), 0, -1); // triming fixed for DokuWiki FS#1690 FS#1713
 }
-
-
-//Setup VIM: ex: et ts=2 enc=utf-8 :
