@@ -2,24 +2,24 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
  * @author Foysol <ragebot1125@gmail.com>
  * @author ninetailz <ninetailz1125@gmail.com>
  * @author Khan M. B. Asad <muhammad2017@gmail.com>
+ * @author Ninetailz <ninetailz1125@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
-$lang['direction']             = 'itr';
-$lang['doublequoteopening']    = '"';
-$lang['doublequoteclosing']    = '"';
-$lang['singlequoteopening']    = '\'';
-$lang['singlequoteclosing']    = '\'';
-$lang['apostrophe']            = '\'';
+$lang['direction']             = 'ltr';
+$lang['doublequoteopening']    = '“';
+$lang['doublequoteclosing']    = '”';
+$lang['singlequoteopening']    = '‘';
+$lang['singlequoteclosing']    = '’';
+$lang['apostrophe']            = '’';
 $lang['btn_edit']              = 'এই পৃষ্ঠা সম্পাদনা করুন';
 $lang['btn_source']            = 'দেখান পাতা উৎস';
 $lang['btn_show']              = 'দেখান পৃষ্ঠা';
 $lang['btn_create']            = 'এই পৃষ্ঠা তৈরি করুন';
 $lang['btn_search']            = 'অনুসন্ধান';
-$lang['btn_save']              = 'Save';
 $lang['btn_preview']           = 'পূর্বরূপ';
 $lang['btn_top']               = 'উপরে ফিরে যান ';
 $lang['btn_newer']             = '<< আরো সাম্প্রতিক';
@@ -37,7 +37,6 @@ $lang['btn_update']            = 'আধুনিক করা';
 $lang['btn_delete']            = 'মুছে ফেলা';
 $lang['btn_back']              = 'পিছনে';
 $lang['btn_backlink']          = 'ব্যাকলিঙ্কগুলি';
-$lang['btn_backtomedia']       = 'পিছনে Mediafile নির্বাচনে যান';
 $lang['btn_subscribe']         = 'সাবস্ক্রিপশন পরিচালনা করুন';
 $lang['btn_profile']           = 'প্রোফাইল আপডেট করুন';
 $lang['btn_reset']             = 'রিসেট করুন';
@@ -50,7 +49,9 @@ $lang['btn_register']          = 'খাতা';
 $lang['btn_apply']             = 'প্রয়োগ করা';
 $lang['btn_media']             = 'মিডিয়া ম্যানেজার';
 $lang['btn_deleteuser']        = 'আমার অ্যাকাউন্ট অপসারণ করুন';
-$lang['loggedinas']            = 'লগ ইন';
+$lang['btn_img_backto']        = 'ফিরে যান %s';
+$lang['btn_mediaManager']      = 'মিডিয়া ম্যানেজারে দেখুন';
+$lang['loggedinas']            = 'লগ ইন:';
 $lang['user']                  = 'ইউজারনেম';
 $lang['pass']                  = 'পাসওয়ার্ড';
 $lang['newpass']               = 'নতুন পাসওয়ার্ড';
@@ -96,12 +97,12 @@ $lang['license']               = 'অন্যথায় নোট যেখ
 $lang['licenseok']             = 'দ্রষ্টব্য: আপনি নিম্নলিখিত লাইসেন্সের অধীনে আপনার বিষয়বস্তু লাইসেন্স সম্মত হন এই পৃষ্ঠার সম্পাদনার দ্বারা:';
 $lang['searchmedia']           = 'অনুসন্ধান ফাইলের নাম:';
 $lang['searchmedia_in']        = 'অনুসন্ধান %s -এ';
-$lang['txt_upload']            = 'আপলোড করার জন্য নির্বাচন করুন ফাইল';
-$lang['txt_filename']          = 'হিসাবে আপলোড করুন (ঐচ্ছিক)';
+$lang['txt_upload']            = 'আপলোড করার জন্য নির্বাচন করুন ফাইল:';
+$lang['txt_filename']          = 'হিসাবে আপলোড করুন (ঐচ্ছিক):';
 $lang['txt_overwrt']           = 'বিদ্যমান ফাইল মুছে যাবে';
 $lang['maxuploadsize']         = 'সর্বোচ্চ আপলোড করুন. %s-ফাইলের প্রতি.';
-$lang['lockedby']              = 'বর্তমানে দ্বারা লক';
-$lang['lockexpire']            = 'তালা এ মেয়াদ শেষ';
+$lang['lockedby']              = 'বর্তমানে দ্বারা লক:';
+$lang['lockexpire']            = 'তালা এ মেয়াদ শেষ:';
 $lang['js']['willexpire']      = 'এই পৃষ্ঠার সম্পাদনার জন্য আপনার লক এক মিনিটের মধ্যে মেয়াদ শেষ সম্পর্কে. \ দ্বন্দ্ব লক টাইমার রিসেট প্রিভিউ বাটন ব্যবহার এড়াতে.';
 $lang['js']['notsavedyet']     = 'অসংরক্ষিত পরিবর্তন হারিয়ে যাবে.';
 $lang['js']['searchmedia']     = 'ফাইলের জন্য অনুসন্ধান';
@@ -146,7 +147,6 @@ $lang['js']['media_overwrt']   = 'বর্তমান ফাইল ওভা
 $lang['rssfailed']             = 'ফিডটি জোগাড় করতে গিয়ে একটি ত্রুটি ঘটেছে:';
 $lang['nothingfound']          = 'কিছু পাওয়া যায়নি।';
 $lang['mediaselect']           = 'মিডিয়া ফাইল';
-$lang['fileupload']            = 'মিডিয়া ফাইল আপলোড';
 $lang['uploadsucc']            = 'আপলোড সফল';
 $lang['uploadfail']            = 'আপলোড ব্যর্থ। অনুমতি জনিত ত্রুটি কী?';
 $lang['uploadwrong']           = 'আপলোড প্রত্যাখ্যাত। এই ফাইল এক্সটেনশন অননুমোদিত।';
@@ -158,3 +158,69 @@ $lang['uploadsize']            = 'আপলোডকৃত ফাইলটি 
 $lang['deletesucc']            = '"%s" ফাইলটি মুছে ফেলা হয়েছে।';
 $lang['deletefail']            = '"%s" ডিলিট করা যায়নি - অনুমতি আছে কি না দেখুন।';
 $lang['mediainuse']            = '"%s" ফাইলটি মোছা হয়নি - এটি এখনো ব্যবহৃত হচ্ছে।';
+$lang['namespaces']            = 'নামস্থান';
+$lang['mediafiles']            = 'ফাইল পাওয়া যাবে ';
+$lang['accessdenied']          = 'আপনি এই পৃষ্ঠাটি দেখতে অনুমতি দেওয়া হয়নি';
+$lang['mediausage']            = 'এই ফাইলের উল্লেখ নিম্নলিখিত সিনট্যাক্স ব্যবহার করুন:';
+$lang['mediaview']             = 'মূল ফাইলটি দেখুন';
+$lang['mediaroot']             = 'মূল';
+$lang['mediaupload']           = 'এখানে বর্তমান নামস্থান একটি ফাইল আপলোড করুন. , Subnamespaces তৈরি আপনি ফাইল নির্বাচন পরে কোলন দ্বারা বিভাজিত আপনার ফাইলের নাম তাদের পূর্বে লিখুন করুন. কোন ফাইল এছাড়াও ড্র্যাগ এবং ড্রপ দ্বারা নির্বাচন করা সম্ভব.';
+$lang['mediaextchange']        = 'ফাইল এক্সটেনশন .%s থেকে .%s\'এ পরিবর্তন হলো !';
+$lang['reference']             = 'তথ্যসূত্রের জন্য ';
+$lang['ref_inuse']             = 'এই ফাইল মুছে ফেলা যাবে না কারণ এটি এখনও ব্যবহৃত হচ্ছে নিম্নলিখিত পাতা দ্বারা:';
+$lang['ref_hidden']            = 'এই পাতায় কিছু রেফারেন্স পড়ার আপনার আনুমতি নেই';
+$lang['hits']                  = 'সফল ';
+$lang['quickhits']             = 'পৃষ্ঠা মেলে';
+$lang['toc']                   = 'সূচীপত্র';
+$lang['current']               = 'বর্তমান';
+$lang['yours']                 = 'আপনার সংস্করণ
+';
+$lang['diff']                  = 'বর্তমান সংস্করণের পার্থক্য দেখান ';
+$lang['diff2']                 = 'নির্বাচিত সংস্করণের মধ্যে পার্থক্য দেখান ';
+$lang['diff_type']             = 'পার্থক্য দেখুন:';
+$lang['diff_inline']           = 'ইনলাইন';
+$lang['diff_side']             = 'পাশাপাশি';
+$lang['diffprevrev']           = 'পূর্ববর্তী সংস্করণ';
+$lang['diffnextrev']           = 'পরবর্তী সংস্করণ';
+$lang['difflastrev']           = 'সর্বশেষ সংস্করণ';
+$lang['diffbothprevrev']       = 'উভয় পক্ষের পূর্ববর্তী সংস্করণ';
+$lang['diffbothnextrev']       = 'উভয় পক্ষের পরবর্তী সংস্করণ';
+$lang['line']                  = 'লাইন';
+$lang['breadcrumb']            = 'ট্রেস:';
+$lang['youarehere']            = 'আপনি এখানে আছেন:';
+$lang['lastmod']               = 'শেষ বার পরিমার্জিত';
+$lang['by']                    = 'দ্বারা';
+$lang['deleted']               = 'মুছে ফেলা';
+$lang['created']               = 'তৈরি করা';
+$lang['restored']              = 'পুরানো সংস্করণের পুনঃস্থাপন (%s)';
+$lang['external_edit']         = 'বাহ্যিক সম্পাদনা';
+$lang['summary']               = 'সম্পাদনা সারাংশ';
+$lang['noflash']               = 'এ href="http://www.adobe.com/products/flashplayer/"> অ্যাডোবি ফ্ল্যাশ প্লাগইন </a> এই সামগ্রী প্রদর্শন করার জন্য প্রয়োজন হয়.';
+$lang['download']              = 'ডাউনলোড স্নিপেট ';
+$lang['tools']                 = 'সরঞ্জামসমূহ';
+$lang['user_tools']            = 'ব্যবহারকারীর সরঞ্জামসমূহ';
+$lang['site_tools']            = 'সাইটের সরঞ্জামসমূহ';
+$lang['page_tools']            = 'পৃষ্ঠার সরঞ্জামসমূহ';
+$lang['skip_to_content']       = 'বিষয়ে এড়িয়ে যান';
+$lang['sidebar']               = 'সাইডবার';
+$lang['mail_newpage']          = 'পৃষ্ঠা যোগ করা হয়েছে:';
+$lang['mail_changed']          = 'পৃষ্ঠা পরিবর্তন করা হয়েছে:';
+$lang['mail_subscribe_list']   = 'পৃষ্ঠাগুলির নামস্থান পরিবর্তন:';
+$lang['mail_new_user']         = 'নতুন ব্যবহারকারী:';
+$lang['mail_upload']           = 'ফাইল আপলোড করেছেন:';
+$lang['changes_type']          = 'দেখুন পরিবর্তনসমূহ';
+$lang['pages_changes']         = 'পৃষ্ঠাগুলি';
+$lang['media_changes']         = 'মিডিয়া ফাইলগুলি';
+$lang['both_changes']          = 'পেজ এবং মিডিয়া ফাইল উভয়েই';
+$lang['qb_bold']               = 'গাঢ় লেখা';
+$lang['qb_italic']             = 'বাঁকা লেখা';
+$lang['qb_underl']             = 'আন্ডারলাইন টেক্সট';
+$lang['qb_code']               = 'মোনোস্কেপ লেখা';
+$lang['qb_strike']             = 'স্ট্রাইক মাধ্যমে টেক্সট';
+$lang['qb_h1']                 = 'স্তর 1 শিরোনাম';
+$lang['qb_h2']                 = 'স্তর 2 শিরোনাম';
+$lang['qb_h3']                 = 'স্তর 3 শিরোনাম';
+$lang['qb_h4']                 = 'স্তর 4 শিরোনাম';
+$lang['qb_h5']                 = 'স্তর 5 শিরোনাম';
+$lang['qb_h']                  = 'শিরোনাম';
+$lang['qb_hs']                 = 'নির্বাচন করুন শিরোনাম';
