@@ -2,7 +2,7 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
  * @author Bohumir Zamecnik <bohumir@zamecnik.org>
  * @author Tomas Valenta <t.valenta@sh.cvut.cz>
  * @author Tomas Valenta <tomas@valenta.cz>
@@ -15,8 +15,11 @@
  * @author Jakub A. Těšínský (j@kub.cz)
  * @author mkucera66@seznam.cz
  * @author Zbyněk Křivka <krivka@fit.vutbr.cz>
- * @author Gerrit Uitslag <klapinklapin@gmail.com>
  * @author Petr Klíma <qaxi@seznam.cz>
+ * @author Radovan Buroň <radovan@buron.cz>
+ * @author Viktor Zavadil <vzavadil@newps.cz>
+ * @author Jaroslav Lichtblau <jlichtblau@seznam.cz>
+ * @author Turkislav <turkislav@blabla.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -48,8 +51,7 @@ $lang['btn_update']            = 'Aktualizovat';
 $lang['btn_delete']            = 'Vymazat';
 $lang['btn_back']              = 'Zpět';
 $lang['btn_backlink']          = 'Zpětné odkazy';
-$lang['btn_backtomedia']       = 'Zpět do Výběru dokumentu';
-$lang['btn_subscribe']         = 'Odebírat emailem změny stránky';
+$lang['btn_subscribe']         = 'Odebírat e-mailem změny stránky';
 $lang['btn_profile']           = 'Upravit profil';
 $lang['btn_reset']             = 'Reset';
 $lang['btn_resendpwd']         = 'Nastavit nové heslo';
@@ -61,12 +63,14 @@ $lang['btn_register']          = 'Registrovat';
 $lang['btn_apply']             = 'Použít';
 $lang['btn_media']             = 'Správa médií';
 $lang['btn_deleteuser']        = 'Odstranit můj účet';
-$lang['loggedinas']            = 'Přihlášen(a) jako';
+$lang['btn_img_backto']        = 'Zpět na %s';
+$lang['btn_mediaManager']      = 'Zobrazit ve správě médií';
+$lang['loggedinas']            = 'Přihlášen(a) jako:';
 $lang['user']                  = 'Uživatelské jméno';
 $lang['pass']                  = 'Heslo';
 $lang['newpass']               = 'Nové heslo';
 $lang['oldpass']               = 'Současné heslo';
-$lang['passchk']               = 'ještě jednou';
+$lang['passchk']               = 'Zopakovat';
 $lang['remember']              = 'Přihlásit se nastálo';
 $lang['fullname']              = 'Celé jméno';
 $lang['email']                 = 'E-mail';
@@ -76,38 +80,41 @@ $lang['badpassconfirm']        = 'Bohužel špatné heslo';
 $lang['minoredit']             = 'Drobné změny';
 $lang['draftdate']             = 'Koncept automaticky uložen v';
 $lang['nosecedit']             = 'Stránka byla v mezičase změněna. Informace o sekci již nebylo platné, byla načtena celá stránka.';
+$lang['searchcreatepage']      = 'Pokud jste nenašli, co hledáte, zkuste požadovanou stránku sami vytvořit stisknutím tlačítka \'\'Vytvořit stránku\'\'.';
 $lang['regmissing']            = 'Musíte vyplnit všechny údaje.';
 $lang['reguexists']            = 'Uživatel se stejným jménem už je zaregistrován.';
-$lang['regsuccess']            = 'Uživatelský účet byl vytvořen a heslo zasláno mailem.';
+$lang['regsuccess']            = 'Uživatelský účet byl vytvořen a heslo zasláno e-mailem.';
 $lang['regsuccess2']           = 'Uživatelský účet byl vytvořen.';
+$lang['regfail']               = 'Uživatelský profil nemohl být vytvořen.';
 $lang['regmailfail']           = 'Zdá se, že nastala chyba při posílání mailu s heslem. Zkuste kontaktovat správce.';
-$lang['regbadmail']            = 'Zadaná mailová adresa není platná. Pokud si myslíte, že to je špatně, zkuste kontaktovat správce.';
+$lang['regbadmail']            = 'Zadaná e-mailová adresa není platná. Pokud si myslíte, že to je špatně, zkuste kontaktovat správce.';
 $lang['regbadpass']            = 'Heslo nebylo zadáno dvakrát stejně, zkuste to prosím znovu.';
 $lang['regpwmail']             = 'Vaše heslo do systému DokuWiki';
 $lang['reghere']               = 'Nemáte uživatelský účet? Zřiďte si ho';
 $lang['profna']                = 'Tato wiki neumožňuje změnu profilu';
 $lang['profnochange']          = 'Žádné změny nebyly provedeny.';
-$lang['profnoempty']           = 'Nelze zadat prázdné jméno nebo mailová adresa.';
+$lang['profnoempty']           = 'Nelze vynechat jméno nebo e-mailovou adresu.';
 $lang['profchanged']           = 'Uživatelský profil změněn.';
 $lang['profnodelete']          = 'Tato wiki nepodporuje mazání uživatelů';
 $lang['profdeleteuser']        = 'Smazat účet';
 $lang['profdeleted']           = 'Váš uživatelský účet byl z této wiki smazán';
 $lang['profconfdelete']        = 'Chci smazat můj účet z této wiki. <br/> Tato akce je nevratná.';
 $lang['profconfdeletemissing'] = 'Potvrzovací tlačítko nezaškrtnuto';
+$lang['proffail']              = 'Uživatelský profil nebyl aktualizován.';
 $lang['pwdforget']             = 'Zapomněli jste heslo? Nechte si zaslat nové';
 $lang['resendna']              = 'Tato wiki neumožňuje zasílání nových hesel.';
 $lang['resendpwd']             = 'Nastavit nové heslo pro';
 $lang['resendpwdmissing']      = 'Musíte vyplnit všechny položky.';
 $lang['resendpwdnouser']       = 'Bohužel takový uživatel v systému není.';
 $lang['resendpwdbadauth']      = 'Autorizační kód není platný. Zadali jste opravdu celý odkaz na potvrzovací stránku?';
-$lang['resendpwdconfirm']      = 'Odkaz na potvrzovací stránku byl odeslán mailem.';
-$lang['resendpwdsuccess']      = 'Vaše nové heslo bylo odesláno emailem.';
+$lang['resendpwdconfirm']      = 'Odkaz na potvrzovací stránku byl odeslán e-mailem.';
+$lang['resendpwdsuccess']      = 'Vaše nové heslo bylo odesláno e-mailem.';
 $lang['license']               = 'Kromě míst, kde je explicitně uvedeno jinak, je obsah této wiki licencován pod následující licencí:';
 $lang['licenseok']             = 'Poznámka: Tím, že editujete tuto stránku, souhlasíte, aby váš obsah byl licencován pod následující licencí:';
 $lang['searchmedia']           = 'Hledat jméno souboru:';
 $lang['searchmedia_in']        = 'Hledat v %s';
-$lang['txt_upload']            = 'Vyberte soubor jako přílohu';
-$lang['txt_filename']          = 'Wiki jméno (volitelné)';
+$lang['txt_upload']            = 'Vyberte soubor jako přílohu:';
+$lang['txt_filename']          = 'Wiki jméno (volitelné):';
 $lang['txt_overwrt']           = 'Přepsat existující soubor';
 $lang['maxuploadsize']         = 'Max. velikost souboru %s';
 $lang['lockedby']              = 'Právě zamknuto:';
@@ -158,7 +165,6 @@ $lang['js']['media_overwrt']   = 'Přepsat existující soubory';
 $lang['rssfailed']             = 'Nastala chyba při vytváření tohoto RSS: ';
 $lang['nothingfound']          = 'Nic nenalezeno.';
 $lang['mediaselect']           = 'Výběr dokumentu';
-$lang['fileupload']            = 'Načtení dokumentu';
 $lang['uploadsucc']            = 'Přenos proběhl v pořádku';
 $lang['uploadfail']            = 'Chyba při načítání. Možná kvůli špatně nastaveným právům?';
 $lang['uploadwrong']           = 'Načtení souboru s takovouto příponou není dovoleno.';
@@ -192,10 +198,15 @@ $lang['difflink']              = 'Odkaz na výstup diff';
 $lang['diff_type']             = 'Zobrazit rozdíly:';
 $lang['diff_inline']           = 'Vložené';
 $lang['diff_side']             = 'Přidané';
+$lang['diffprevrev']           = 'Předchozí verze';
+$lang['diffnextrev']           = 'Následující verze';
+$lang['difflastrev']           = 'Poslední revize';
+$lang['diffbothprevrev']       = 'Obě strany předchozí revize';
+$lang['diffbothnextrev']       = 'Obě strany příští revize';
 $lang['line']                  = 'Řádek';
-$lang['breadcrumb']            = 'Historie';
-$lang['youarehere']            = 'Umístění';
-$lang['lastmod']               = 'Poslední úprava';
+$lang['breadcrumb']            = 'Historie:';
+$lang['youarehere']            = 'Umístění:';
+$lang['lastmod']               = 'Poslední úprava:';
 $lang['by']                    = 'autor:';
 $lang['deleted']               = 'odstraněno';
 $lang['created']               = 'vytvořeno';
@@ -244,24 +255,21 @@ $lang['qb_sig']                = 'Vložit podpis';
 $lang['qb_smileys']            = 'Emotikony';
 $lang['qb_chars']              = 'Speciální znaky';
 $lang['upperns']               = 'skočit do nadřazeného jmenného prostoru';
-$lang['admin_register']        = 'Přidat nového uživatele';
 $lang['metaedit']              = 'Upravit Metadata';
 $lang['metasaveerr']           = 'Chyba při zápisu metadat';
 $lang['metasaveok']            = 'Metadata uložena';
-$lang['btn_img_backto']        = 'Zpět na %s';
-$lang['img_title']             = 'Titulek';
-$lang['img_caption']           = 'Popis';
-$lang['img_date']              = 'Datum';
-$lang['img_fname']             = 'Jméno souboru';
-$lang['img_fsize']             = 'Velikost';
-$lang['img_artist']            = 'Autor fotografie';
-$lang['img_copyr']             = 'Copyright';
-$lang['img_format']            = 'Formát';
-$lang['img_camera']            = 'Typ fotoaparátu';
-$lang['img_keywords']          = 'Klíčová slova';
-$lang['img_width']             = 'Šířka';
-$lang['img_height']            = 'Výška';
-$lang['btn_mediaManager']           = 'Zobrazit ve správě médií';
+$lang['img_title']             = 'Titulek:';
+$lang['img_caption']           = 'Popis:';
+$lang['img_date']              = 'Datum:';
+$lang['img_fname']             = 'Jméno souboru:';
+$lang['img_fsize']             = 'Velikost:';
+$lang['img_artist']            = 'Autor fotografie:';
+$lang['img_copyr']             = 'Copyright:';
+$lang['img_format']            = 'Formát:';
+$lang['img_camera']            = 'Typ fotoaparátu:';
+$lang['img_keywords']          = 'Klíčová slova:';
+$lang['img_width']             = 'Šířka:';
+$lang['img_height']            = 'Výška:';
 $lang['subscr_subscribe_success'] = '%s byl přihlášen do seznamu odběratelů %s';
 $lang['subscr_subscribe_error'] = 'Došlo k chybě při přihlašování %s do seznamu odběratelů %s';
 $lang['subscr_subscribe_noaddress'] = 'K Vašemu loginu neexistuje žádná adresa, nemohl jste být přihlášen do seznamu odběratelů.';
@@ -270,16 +278,15 @@ $lang['subscr_unsubscribe_error'] = 'Došlo k chybě při odhlašování %s ze s
 $lang['subscr_already_subscribed'] = '%s již je přihlášen do seznamu odběratelů %s';
 $lang['subscr_not_subscribed'] = '%s není přihlášen do seznamu odběratelů %s';
 $lang['subscr_m_not_subscribed'] = 'V současné době neodebíráte změny na aktuální stránce nebo ve jmenném prostoru.';
-$lang['subscr_m_new_header']   = 'Přihlásit k odebírání změn emailem';
+$lang['subscr_m_new_header']   = 'Přihlásit k odebírání změn e-mailem';
 $lang['subscr_m_current_header'] = 'Aktuální odběratelé změn';
-$lang['subscr_m_unsubscribe']  = 'Odhlásit z odběru změn emailem';
-$lang['subscr_m_subscribe']    = 'Přihlásit se k odběru změn emailem';
+$lang['subscr_m_unsubscribe']  = 'Odhlásit z odběru změn e-mailem';
+$lang['subscr_m_subscribe']    = 'Přihlásit se k odběru změn e-mailem';
 $lang['subscr_m_receive']      = 'Přejete si dostávat';
-$lang['subscr_style_every']    = 'email pro každou změnu';
-$lang['subscr_style_digest']   = 'souhrnný email změn pro každou stránku (každé %.2f dny/dní)';
-$lang['subscr_style_list']     = 'seznam změněných stránek od posledního emailu (každé %.2f dny/dní)';
+$lang['subscr_style_every']    = 'e-mail pro každou změnu';
+$lang['subscr_style_digest']   = 'souhrnný e-mail změn pro každou stránku (každé %.2f dny/dní)';
+$lang['subscr_style_list']     = 'seznam změněných stránek od posledního e-mailu (každé %.2f dny/dní)';
 $lang['authtempfail']          = 'Autentizace uživatelů je dočasně nedostupná. Pokud tento problém přetrvává, informujte prosím správce této wiki.';
-$lang['authpwdexpire']         = 'Platnost vašeho hesla vyprší za %d dní, měli byste ho změnit co nejdříve.';
 $lang['i_chooselang']          = 'Vyberte si jazyk';
 $lang['i_installer']           = 'Instalace DokuWiki';
 $lang['i_wikiname']            = 'Název wiki';
@@ -289,6 +296,7 @@ $lang['i_problems']            = 'Instalátor narazil na níže popsané problé
 $lang['i_modified']            = 'Instalátor bude z bezpečnostních důvodů pracovat pouze s čistou a ještě neupravenou instalací DokuWiki. Buď znovu rozbalte soubory z instalačního balíčku, nebo zkuste prostudovat <a href="http://dokuwiki.org/install">instrukce pro instalaci DokuWiki</a>.';
 $lang['i_funcna']              = 'PHP funkce <code>%s</code> není dostupná. Váš webhosting ji možná z nějakého důvodu vypnul.';
 $lang['i_phpver']              = 'Verze vaší instalace PHP <code>%s</code> je nižší než požadovaná <code>%s</code>. Budete muset aktualizovat svou instalaci PHP.';
+$lang['i_mbfuncoverload']      = 'mbstring.func_overload musí být vypnut v php.ini pro běh DokuWiki.';
 $lang['i_permfail']            = 'DokuWiki nemůže zapisovat do <code>%s</code>. Budete muset opravit práva k tomuto adresáři.';
 $lang['i_confexists']          = '<code>%s</code> již existuje';
 $lang['i_writeerr']            = 'Nelze vytvořit <code>%s</code>. Budete muset zkontrolovat práva k souborům či adresářům a vytvořit tento soubor ručně.';
@@ -338,7 +346,12 @@ $lang['media_perm_read']       = 'Bohužel, nemáte práva číst soubory.';
 $lang['media_perm_upload']     = 'Bohužel, nemáte práva nahrávat soubory.';
 $lang['media_update']          = 'Nahrát novou verzi';
 $lang['media_restore']         = 'Obnovit tuto verzi';
+$lang['media_acl_warning']     = 'Tento seznam nemusí být úplný z důvodu omezení práv ACL a skrytým stránkám.';
 $lang['currentns']             = 'Aktuální jmenný prostor';
 $lang['searchresult']          = 'Výsledek hledání';
 $lang['plainhtml']             = 'Čisté HTML';
 $lang['wikimarkup']            = 'Wiki jazyk';
+$lang['page_nonexist_rev']     = 'Stránka neexistovala na %s. Byla vytvořena dodatečne na <a href="%s">%s</a>.';
+$lang['unable_to_parse_date']  = 'Nelze rozebrat parametr "%s".';
+$lang['email_signature_text'] = 'Tento e-mail byl automaticky vygenerován systémem DokuWiki
+@DOKUWIKIURL@';
