@@ -2,7 +2,7 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
  * @author Antono Vasiljev <esperanto.minsk ĈE tut.by>
  * @author Felipe Castro <fefcas@yahoo.com.br>
  * @author Felipe Castro <fefcas@uol.com.br>
@@ -17,7 +17,7 @@ $lang['doublequoteopening']    = '“';
 $lang['doublequoteclosing']    = '”';
 $lang['singlequoteopening']    = '‘';
 $lang['singlequoteclosing']    = '’';
-$lang['apostrophe']            = '\'';
+$lang['apostrophe']            = '’';
 $lang['btn_edit']              = 'Redakti la paĝon';
 $lang['btn_source']            = 'Montri fontan tekston';
 $lang['btn_show']              = 'Montri paĝon';
@@ -41,7 +41,6 @@ $lang['btn_update']            = 'Aktualigi';
 $lang['btn_delete']            = 'Forigi';
 $lang['btn_back']              = 'Retroiri';
 $lang['btn_backlink']          = 'Retroligoj';
-$lang['btn_backtomedia']       = 'Retroiri al elekto de dosiero';
 $lang['btn_subscribe']         = 'Aliĝi al paĝaj modifoj';
 $lang['btn_profile']           = 'Aktualigi profilon';
 $lang['btn_reset']             = 'Rekomenci';
@@ -56,7 +55,7 @@ $lang['btn_media']             = 'Medio-administrilo';
 $lang['btn_deleteuser']        = 'Forigi mian konton';
 $lang['btn_img_backto']        = 'Iri reen al %s';
 $lang['btn_mediaManager']      = 'Rigardi en aŭdvidaĵ-administrilo';
-$lang['loggedinas']            = 'Ensalutinta kiel';
+$lang['loggedinas']            = 'Ensalutinta kiel:';
 $lang['user']                  = 'Uzant-nomo';
 $lang['pass']                  = 'Pasvorto';
 $lang['newpass']               = 'Nova pasvorto';
@@ -71,6 +70,7 @@ $lang['badpassconfirm']        = 'Pardonu, la pasvorto malĝustis';
 $lang['minoredit']             = 'Etaj modifoj';
 $lang['draftdate']             = 'Lasta konservo de la skizo:';
 $lang['nosecedit']             = 'La paĝo ŝanĝiĝis intertempe, sekcio-informo estis malĝisdata, tial la tuta paĝo estas reŝargita.';
+$lang['searchcreatepage']      = 'Se vi ne trovis tion, kion vi serĉis, vi povas krei novan paĝon kun necesa nomo per la koresponda butono.';
 $lang['regmissing']            = 'Pardonu, vi devas plenigi ĉiujn kampojn.';
 $lang['reguexists']            = 'Pardonu, ĉi tiu uzanto-nomo jam ekzistas.';
 $lang['regsuccess']            = 'La uzanto kreiĝis kaj la pasvorto sendiĝis per retpoŝto.';
@@ -101,12 +101,12 @@ $lang['license']               = 'Krom kie rekte indikite, enhavo de tiu ĉi vik
 $lang['licenseok']             = 'Rimarku: redaktante tiun ĉi paĝon vi konsentas publikigi vian enhavon laŭ la jena permesilo:';
 $lang['searchmedia']           = 'Serĉi dosiernomon:';
 $lang['searchmedia_in']        = 'Serĉi en %s';
-$lang['txt_upload']            = 'Elektu dosieron por alŝuti';
-$lang['txt_filename']          = 'Alŝuti kiel (laŭvole)';
+$lang['txt_upload']            = 'Elektu dosieron por alŝuti:';
+$lang['txt_filename']          = 'Alŝuti kiel (laŭvole):';
 $lang['txt_overwrt']           = 'Anstataŭigi ekzistantan dosieron';
 $lang['maxuploadsize']         = 'Alŝuto maks. %s po dosiero.';
-$lang['lockedby']              = 'Nune ŝlosita de';
-$lang['lockexpire']            = 'Ŝlosado ĉesos je';
+$lang['lockedby']              = 'Nune ŝlosita de:';
+$lang['lockexpire']            = 'Ŝlosado ĉesos je:';
 $lang['js']['willexpire']      = 'Vi povos redakti ĉi tiun paĝon post unu minuto.\nSe vi volas nuligi tempokontrolon de la ŝlosado, premu la butonon "Antaŭrigardi".';
 $lang['js']['notsavedyet']     = 'Ne konservitaj modifoj perdiĝos.
 Ĉu vi certe volas daŭrigi la procezon?';
@@ -152,7 +152,6 @@ $lang['js']['media_overwrt']   = 'Anstataûi ekzistantajn dosierojn';
 $lang['rssfailed']             = 'Okazis eraro dum ricevado de la novaĵ-fluo: ';
 $lang['nothingfound']          = 'Ankoraŭ nenio troviĝas tie ĉi.';
 $lang['mediaselect']           = 'Elekto de aŭdvidaĵa dosiero';
-$lang['fileupload']            = 'Alŝuto de aŭdvidaĵa dosiero';
 $lang['uploadsucc']            = 'Alŝuto sukcesis';
 $lang['uploadfail']            = 'Alŝuto malsukcesis. Ĉu eble estas problemoj pro permes-atributoj?';
 $lang['uploadwrong']           = 'Rifuzita alŝuto. Tiu ĉi dosiersufikso estas malpermesata!';
@@ -192,9 +191,9 @@ $lang['difflastrev']           = 'Lasta revizio';
 $lang['diffbothprevrev']       = 'Sur ambaŭ flankoj antaŭa revizio';
 $lang['diffbothnextrev']       = 'Sur ambaŭ flankoj sekva revizio';
 $lang['line']                  = 'Linio';
-$lang['breadcrumb']            = 'Paŝoj';
-$lang['youarehere']            = 'Vi estas ĉi tie';
-$lang['lastmod']               = 'Lastaj ŝanĝoj';
+$lang['breadcrumb']            = 'Paŝoj:';
+$lang['youarehere']            = 'Vi estas ĉi tie:';
+$lang['lastmod']               = 'Lastaj ŝanĝoj:';
 $lang['by']                    = 'de';
 $lang['deleted']               = 'forigita';
 $lang['created']               = 'kreita';
@@ -243,22 +242,21 @@ $lang['qb_sig']                = 'Inkluzivi subskribon';
 $lang['qb_smileys']            = 'Ridetuloj';
 $lang['qb_chars']              = 'Specialaj signaĵoj';
 $lang['upperns']               = 'saltu al la parenca nomspaco';
-$lang['admin_register']        = 'Aldoni novan uzanton';
 $lang['metaedit']              = 'Redakti metadatumaron';
 $lang['metasaveerr']           = 'La konservo de metadatumaro malsukcesis';
 $lang['metasaveok']            = 'La metadatumaro konserviĝis';
-$lang['img_title']             = 'Titolo';
-$lang['img_caption']           = 'Priskribo';
-$lang['img_date']              = 'Dato';
-$lang['img_fname']             = 'Dosiernomo';
-$lang['img_fsize']             = 'Grandeco';
-$lang['img_artist']            = 'Fotisto';
-$lang['img_copyr']             = 'Kopirajtoj';
-$lang['img_format']            = 'Formato';
-$lang['img_camera']            = 'Kamerao';
-$lang['img_keywords']          = 'Ŝlosilvortoj';
-$lang['img_width']             = 'Larĝeco';
-$lang['img_height']            = 'Alteco';
+$lang['img_title']             = 'Titolo:';
+$lang['img_caption']           = 'Priskribo:';
+$lang['img_date']              = 'Dato:';
+$lang['img_fname']             = 'Dosiernomo:';
+$lang['img_fsize']             = 'Grandeco:';
+$lang['img_artist']            = 'Fotisto:';
+$lang['img_copyr']             = 'Kopirajtoj:';
+$lang['img_format']            = 'Formato:';
+$lang['img_camera']            = 'Kamerao:';
+$lang['img_keywords']          = 'Ŝlosilvortoj:';
+$lang['img_width']             = 'Larĝeco:';
+$lang['img_height']            = 'Alteco:';
 $lang['subscr_subscribe_success'] = 'Aldonis %s al la abonlisto por %s';
 $lang['subscr_subscribe_error'] = 'Eraro dum aldono de %s al la abonlisto por %s';
 $lang['subscr_subscribe_noaddress'] = 'Ne estas adreso ligita al via ensaluto, ne eblas aldoni vin al la abonlisto';
@@ -276,7 +274,6 @@ $lang['subscr_style_every']    = 'retpoŝtaĵo pro ĉiu ŝanĝo';
 $lang['subscr_style_digest']   = 'resuma retpoŝtaĵo de ŝanĝoj por ĉiu paĝo (je %.2f tagoj)';
 $lang['subscr_style_list']     = 'listo de ŝanĝitaj paĝoj ekde la lasta retpoŝtaĵo (je %.2f tagoj)';
 $lang['authtempfail']          = 'La identigo de via uzantonomo estas intertempe maldisponebla. Se tiu ĉi situacio daŭros, bonvolu informi la adminstranton de la vikio.';
-$lang['authpwdexpire']         = 'Via pasvorto malvalidos post %d tagoj, prefere ŝanĝu ĝin baldaũ.';
 $lang['i_chooselang']          = 'Elektu vian lingvon';
 $lang['i_installer']           = 'Instalilo de DokuWiki';
 $lang['i_wikiname']            = 'Nomo de la vikio';
@@ -340,3 +337,5 @@ $lang['currentns']             = 'Aktuala nomspaco';
 $lang['searchresult']          = 'Serĉrezulto';
 $lang['plainhtml']             = 'Plena HTML';
 $lang['wikimarkup']            = 'Vikiteksto';
+$lang['email_signature_text'] = 'Tiu ĉi mesaĝo kreiĝis de DokuWiki ĉe
+@DOKUWIKIURL@';
