@@ -1,11 +1,12 @@
 <?php
+
 /**
- * Basque language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
  * @author Xabi Ezpeleta <xezpeleta@mendikute.com>
  * @author Inko Illarramendi <inko.i.a@gmail.com>
  * @author Zigor Astarbe <astarbe@gmail.com>
+ * @author Yadav Gowda <yadav.gowda@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -37,7 +38,6 @@ $lang['btn_update']            = 'Eguneratu';
 $lang['btn_delete']            = 'Ezabatu';
 $lang['btn_back']              = 'Atzera';
 $lang['btn_backlink']          = 'Itzulera estekak';
-$lang['btn_backtomedia']       = 'Atzera Multimedia Fitxategiaren Aukeraketara';
 $lang['btn_subscribe']         = 'Harpidetu Orri Aldaketetara';
 $lang['btn_profile']           = 'Eguneratu Profila ';
 $lang['btn_reset']             = 'Aldaketak Desegin';
@@ -49,7 +49,10 @@ $lang['btn_revert']            = 'Berrezarri';
 $lang['btn_register']          = 'Erregistratu';
 $lang['btn_apply']             = 'Baieztatu';
 $lang['btn_media']             = 'Media Kudeatzailea';
-$lang['loggedinas']            = 'Erabiltzailea';
+$lang['btn_deleteuser']        = 'Nire kontua kendu';
+$lang['btn_img_backto']        = 'Atzera hona %s';
+$lang['btn_mediaManager']      = 'Media kudeatzailean ikusi';
+$lang['loggedinas']            = 'Erabiltzailea:';
 $lang['user']                  = 'Erabiltzailea';
 $lang['pass']                  = 'Pasahitza';
 $lang['newpass']               = 'Pasahitz berria';
@@ -63,6 +66,7 @@ $lang['badlogin']              = 'Barkatu, prozesuak huts egin du; saiatu berriz
 $lang['minoredit']             = 'Aldaketa Txikiak';
 $lang['draftdate']             = 'Zirriborroa automatikoki gorde da hemen:';
 $lang['nosecedit']             = 'Orria aldatua izan da bitartean, info atala zaharkituta geratu da, orri osoa kargatu da horren ordez.';
+$lang['searchcreatepage']      = 'Bilatzen zabiltzana aurkitu ez baduzu, zuk zeuk sortu dezakezu orri berri bat bilaketa ostean \'\'Sortu orri hau\'\' erabiliz.';
 $lang['regmissing']            = 'Barkatu, hutsune guztiak bete behar dituzu.';
 $lang['reguexists']            = 'Barkatu, izen bereko erabiltzailea existitzen da.';
 $lang['regsuccess']            = 'Erabiltzailea sortu da. Pasahitza mailez bidaliko zaizu.';
@@ -76,6 +80,7 @@ $lang['profna']                = 'Wiki honek ez du profilaren aldaketa ahalbidet
 $lang['profnochange']          = 'Aldaketarik ez, ez dago egiteko ezer.';
 $lang['profnoempty']           = 'Izen edota e-posta hutsa ez dago onartua.';
 $lang['profchanged']           = 'Erabiltzaile profila arrakastaz eguneratua.';
+$lang['profdeleteuser']        = 'Kontua ezabatu';
 $lang['pwdforget']             = 'Pasahitza ahaztu duzu? Eskuratu berri bat';
 $lang['resendna']              = 'Wiki honek ez du pasahitz berbidalketa onartzen.';
 $lang['resendpwd']             = '-entzat pasahitza berria ezarri';
@@ -88,8 +93,8 @@ $lang['license']               = 'Besterik esan ezean, wiki hontako edukia ondor
 $lang['licenseok']             = 'Oharra: Orri hau editatzean, zure edukia ondorengo lizentziapean argitaratzea onartzen duzu: ';
 $lang['searchmedia']           = 'Bilatu fitxategi izena:';
 $lang['searchmedia_in']        = 'Bilatu %s-n';
-$lang['txt_upload']            = 'Ireki nahi den fitxategia aukeratu';
-$lang['txt_filename']          = 'Idatzi wikiname-a (aukerazkoa)';
+$lang['txt_upload']            = 'Ireki nahi den fitxategia aukeratu:';
+$lang['txt_filename']          = 'Idatzi wikiname-a (aukerazkoa):';
 $lang['txt_overwrt']           = 'Oraingo fitxategiaren gainean idatzi';
 $lang['lockedby']              = 'Momentu honetan blokeatzen:';
 $lang['lockexpire']            = 'Blokeaketa iraungitzen da:';
@@ -137,7 +142,6 @@ $lang['js']['media_overwrt']   = 'Dauden fitxategiak berridatzi';
 $lang['rssfailed']             = 'Errorea gertatu da feed hau irakurtzean:';
 $lang['nothingfound']          = 'Ez da ezer aurkitu.';
 $lang['mediaselect']           = 'Aukeratu Multimedia fitxategia';
-$lang['fileupload']            = 'Igo Multimedia Fitxategia';
 $lang['uploadsucc']            = 'Igoera arrakastatsua';
 $lang['uploadfail']            = 'Igoerak huts egin du. Baimen arazoengatik agian?';
 $lang['uploadwrong']           = 'Fitxategi igoera ukatua. Fitxategi-luzapen hau debekatua dago!';
@@ -172,9 +176,9 @@ $lang['diff_type']             = 'Ikusi diferentziak:';
 $lang['diff_inline']           = 'Lerro tartean';
 $lang['diff_side']             = 'Ondoz ondo';
 $lang['line']                  = 'Marra';
-$lang['breadcrumb']            = 'Traza';
-$lang['youarehere']            = 'Hemen zaude';
-$lang['lastmod']               = 'Azken aldaketa';
+$lang['breadcrumb']            = 'Traza:';
+$lang['youarehere']            = 'Hemen zaude:';
+$lang['lastmod']               = 'Azken aldaketa:';
 $lang['by']                    = 'egilea:';
 $lang['deleted']               = 'ezabatua';
 $lang['created']               = 'sortua';
@@ -223,24 +227,21 @@ $lang['qb_sig']                = 'Gehitu sinadura';
 $lang['qb_smileys']            = 'Irrifartxoak';
 $lang['qb_chars']              = 'Karaktere Bereziak';
 $lang['upperns']               = 'Jauzi izen-espazio gurasora';
-$lang['admin_register']        = 'Erabiltzaile berria gehitu';
 $lang['metaedit']              = 'Metadatua Aldatu';
 $lang['metasaveerr']           = 'Metadatuaren idazketak huts egin du';
 $lang['metasaveok']            = 'Metadatua gordea';
-$lang['btn_img_backto']            = 'Atzera hona %s';
-$lang['img_title']             = 'Izenburua';
-$lang['img_caption']           = 'Epigrafea';
-$lang['img_date']              = 'Data';
-$lang['img_fname']             = 'Fitxategi izena';
-$lang['img_fsize']             = 'Tamaina';
-$lang['img_artist']            = 'Artista';
-$lang['img_copyr']             = 'Copyright';
-$lang['img_format']            = 'Formatua';
-$lang['img_camera']            = 'Kamera';
-$lang['img_keywords']          = 'Hitz-gakoak';
-$lang['img_width']             = 'Zabalera';
-$lang['img_height']            = 'Altuera';
-$lang['btn_mediaManager']           = 'Media kudeatzailean ikusi';
+$lang['img_title']             = 'Izenburua:';
+$lang['img_caption']           = 'Epigrafea:';
+$lang['img_date']              = 'Data:';
+$lang['img_fname']             = 'Fitxategi izena:';
+$lang['img_fsize']             = 'Tamaina:';
+$lang['img_artist']            = 'Artista:';
+$lang['img_copyr']             = 'Copyright:';
+$lang['img_format']            = 'Formatua:';
+$lang['img_camera']            = 'Kamera:';
+$lang['img_keywords']          = 'Hitz-gakoak:';
+$lang['img_width']             = 'Zabalera:';
+$lang['img_height']            = 'Altuera:';
 $lang['subscr_subscribe_success'] = '%s gehitua %s-ren harpidetza zerrendara';
 $lang['subscr_subscribe_error'] = 'Errorea %s gehitzen %s-ren harpidetza zerrendara';
 $lang['subscr_subscribe_noaddress'] = 'Ez dago helbiderik zure login-arekin lotuta, ezin zara harpidetza zerrendara gehitua izan.';
@@ -258,7 +259,6 @@ $lang['subscr_style_every']    = 'e-posta aldaketa bakoitzean';
 $lang['subscr_style_digest']   = 'e-posta laburbildua orri bakoitzeko aldaketentzat (%.2f egunero)';
 $lang['subscr_style_list']     = 'aldatutako orrien zerrenda azken e-postatik (%.2f egunero)';
 $lang['authtempfail']          = 'Erabiltzaile kautotzea denboraldi batez ez dago erabilgarri. Egoerak hala jarraitzen badu, mesedez, eman honen berri Wiki administratzaileari';
-$lang['authpwdexpire']         = 'Zure pasahitza %d egun barru iraungiko da, laster aldatu beharko zenuke.';
 $lang['i_chooselang']          = 'Hautatu zure hizkuntza';
 $lang['i_installer']           = 'DokuWiki instalatzailea';
 $lang['i_wikiname']            = 'Wiki Izena';
@@ -306,3 +306,5 @@ $lang['media_viewold']         = '%s -n %s';
 $lang['media_edit']            = '%s editatu';
 $lang['media_update']          = 'Bertsio berria igo';
 $lang['media_restore']         = 'Bertsio hau berrezarri';
+$lang['email_signature_text'] = 'Email hau DokuWiki erabiliz sortu da
+@DOKUWIKIURL@';
