@@ -2,7 +2,7 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
  * @author Sébastien Bauer <sebastien.bauer@advalvas.be>
  * @author Antoine Fixary <antoine.fixary@freesbee.fr>
  * @author cumulus <pta-n56@myamail.com>
@@ -32,6 +32,12 @@
  * @author Wild <wild.dagger@free.fr>
  * @author ggallon <gwenael.gallon@mac.com>
  * @author David VANTYGHEM <david.vantyghem@free.fr>
+ * @author Caillot <remicaillot5@gmail.com>
+ * @author Schplurtz le Déboulonné <schplurtz@laposte.net>
+ * @author YoBoY <yoboy@ubuntu-fr.org>
+ * @author james <j.mccann@celcat.com>
+ * @author Pietroni <pietroni@informatique.univ-paris-diderot.fr>
+ * @author Floriang <antispam@floriang.eu>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -52,7 +58,7 @@ $lang['btn_newer']             = '<< Plus récent';
 $lang['btn_older']             = 'Moins récent >>';
 $lang['btn_revs']              = 'Anciennes révisions';
 $lang['btn_recent']            = 'Derniers changements';
-$lang['btn_upload']            = 'Envoyer';
+$lang['btn_upload']            = 'Téléverser';
 $lang['btn_cancel']            = 'Annuler';
 $lang['btn_index']             = 'Plan du site';
 $lang['btn_secedit']           = 'Modifier';
@@ -62,9 +68,8 @@ $lang['btn_admin']             = 'Administrer';
 $lang['btn_update']            = 'Mettre à jour';
 $lang['btn_delete']            = 'Effacer';
 $lang['btn_back']              = 'Retour';
-$lang['btn_backlink']          = 'Liens vers cette page';
-$lang['btn_backtomedia']       = 'Retour à la sélection du fichier média';
-$lang['btn_subscribe']         = 'S\'abonner à cette page';
+$lang['btn_backlink']          = 'Liens de retour';
+$lang['btn_subscribe']         = 'Gérer les abonnements';
 $lang['btn_profile']           = 'Mettre à jour le profil';
 $lang['btn_reset']             = 'Réinitialiser';
 $lang['btn_resendpwd']         = 'Définir un nouveau mot de passe';
@@ -74,11 +79,11 @@ $lang['btn_draftdel']          = 'Effacer le brouillon';
 $lang['btn_revert']            = 'Restaurer';
 $lang['btn_register']          = 'Créer un compte';
 $lang['btn_apply']             = 'Appliquer';
-$lang['btn_media']             = 'Gestionnaire de médias';
+$lang['btn_media']             = 'Gestionnaire Multimédia';
 $lang['btn_deleteuser']        = 'Supprimer mon compte';
-$lang['btn_img_backto']        = 'Retour à %s';
+$lang['btn_img_backto']        = 'Retour vers %s';
 $lang['btn_mediaManager']      = 'Voir dans le gestionnaire de médias';
-$lang['loggedinas']            = 'Connecté en tant que ';
+$lang['loggedinas']            = 'Connecté en tant que :';
 $lang['user']                  = 'Utilisateur';
 $lang['pass']                  = 'Mot de passe';
 $lang['newpass']               = 'Nouveau mot de passe';
@@ -88,20 +93,22 @@ $lang['remember']              = 'Mémoriser';
 $lang['fullname']              = 'Nom';
 $lang['email']                 = 'Adresse de courriel';
 $lang['profile']               = 'Profil utilisateur';
-$lang['badlogin']              = 'L\'utilisateur ou le mot de passe est incorrect.';
+$lang['badlogin']              = 'Le nom d\'utilisateur ou le mot de passe est incorrect.';
 $lang['badpassconfirm']        = 'Désolé, le mot de passe est erroné';
 $lang['minoredit']             = 'Modification mineure';
-$lang['draftdate']             = 'Brouillon enregistré de manière automatique le';
+$lang['draftdate']             = 'Brouillon enregistré automatiquement le';
 $lang['nosecedit']             = 'La page a changé entre temps, les informations de la section sont obsolètes ; la page complète a été chargée à la place.';
+$lang['searchcreatepage']      = 'Si vous n\'avez pas trouvé ce que vous cherchiez, vous pouvez créer ou modifier la page correspondante à votre requête en cliquant sur le bouton approprié.';
 $lang['regmissing']            = 'Désolé, vous devez remplir tous les champs.';
-$lang['reguexists']            = 'Désolé, ce nom d\'utilisateur est déjà utilisé.';
+$lang['reguexists']            = 'Désolé, ce nom d\'utilisateur est déjà pris.';
 $lang['regsuccess']            = 'L\'utilisateur a été créé. Le mot de passe a été expédié par courriel.';
 $lang['regsuccess2']           = 'L\'utilisateur a été créé.';
+$lang['regfail']               = 'L\'utilisateur n\'a pu être crée.';
 $lang['regmailfail']           = 'On dirait qu\'il y a eu une erreur lors de l\'envoi du mot de passe de messagerie. Veuillez contacter l\'administrateur !';
 $lang['regbadmail']            = 'L\'adresse de courriel semble incorrecte. Si vous pensez que c\'est une erreur, contactez l\'administrateur.';
 $lang['regbadpass']            = 'Les deux mots de passe fournis sont différents, veuillez recommencez.';
 $lang['regpwmail']             = 'Votre mot de passe DokuWiki';
-$lang['reghere']               = 'Vous n\'avez pas encore de compte ? Enregistrez-vous ici ';
+$lang['reghere']               = 'Vous n\'avez pas encore de compte ? Inscrivez-vous';
 $lang['profna']                = 'Ce wiki ne permet pas de modifier les profils';
 $lang['profnochange']          = 'Pas de modification, rien à faire.';
 $lang['profnoempty']           = 'Un nom ou une adresse de courriel vide n\'est pas permis.';
@@ -111,6 +118,7 @@ $lang['profdeleteuser']        = 'Supprimer le compte';
 $lang['profdeleted']           = 'Votre compte utilisateur a été supprimé de ce wiki';
 $lang['profconfdelete']        = 'Je veux supprimer mon compte sur ce wiki. </br> Cette action est irréversible.';
 $lang['profconfdeletemissing'] = 'La case de confirmation n\'est pas cochée';
+$lang['proffail']              = 'Le profil utilisateur n\'a pas été mis à jour.';
 $lang['pwdforget']             = 'Mot de passe oublié ? Obtenez-en un nouveau';
 $lang['resendna']              = 'Ce wiki ne permet pas le renvoi de mot de passe.';
 $lang['resendpwd']             = 'Définir un nouveau mot de passe pour';
@@ -123,12 +131,12 @@ $lang['license']               = 'Sauf mention contraire, le contenu de ce wiki
 $lang['licenseok']             = 'Note : En modifiant cette page, vous acceptez que le contenu soit placé sous les termes de la licence suivante :';
 $lang['searchmedia']           = 'Chercher le nom de fichier :';
 $lang['searchmedia_in']        = 'Chercher dans %s';
-$lang['txt_upload']            = 'Sélectionnez un fichier à envoyer ';
-$lang['txt_filename']          = 'Envoyer en tant que (optionnel) ';
+$lang['txt_upload']            = 'Sélectionnez un fichier à envoyer:';
+$lang['txt_filename']          = 'Envoyer en tant que (optionnel):';
 $lang['txt_overwrt']           = 'Écraser le fichier cible (s\'il existe)';
 $lang['maxuploadsize']         = 'Taille d\'envoi maximale : %s par fichier';
-$lang['lockedby']              = 'Actuellement bloqué par';
-$lang['lockexpire']            = 'Le blocage expire à';
+$lang['lockedby']              = 'Actuellement bloqué par:';
+$lang['lockexpire']            = 'Le blocage expire à:';
 $lang['js']['willexpire']      = 'Votre blocage pour la modification de cette page expire dans une minute.\nPour éviter les conflits, utilisez le bouton « Aperçu » pour réinitialiser le minuteur.';
 $lang['js']['notsavedyet']     = 'Les modifications non enregistrées seront perdues. Voulez-vous vraiment continuer ?';
 $lang['js']['searchmedia']     = 'Chercher des fichiers';
@@ -173,7 +181,6 @@ $lang['js']['media_overwrt']   = 'Écraser les fichiers existants';
 $lang['rssfailed']             = 'Une erreur s\'est produite en récupérant ce flux : ';
 $lang['nothingfound']          = 'Pas de réponse.';
 $lang['mediaselect']           = 'Sélection de fichiers';
-$lang['fileupload']            = 'Envoi de fichier';
 $lang['uploadsucc']            = 'Envoi réussi';
 $lang['uploadfail']            = 'L\'envoi a échoué. Les autorisations sont-elles correctes ?';
 $lang['uploadwrong']           = 'Envoi refusé. Cette extension de fichier est interdite !';
@@ -191,7 +198,7 @@ $lang['accessdenied']          = 'Vous n\'êtes pas autorisé à voir cette page
 $lang['mediausage']            = 'Utilisez la syntaxe suivante pour faire référence à ce fichier :';
 $lang['mediaview']             = 'Afficher le fichier original';
 $lang['mediaroot']             = 'racine';
-$lang['mediaupload']           = 'Envoyez un fichier dans la catégorie actuelle. Pour créer des sous-catégories, préfixez en le nom du fichier séparées par un double-point, après avoir choisis le(s) fichier(s). Le(s) fichier(s) peuvent également être envoyé(s) par glisser-déposer (drag & drop)';
+$lang['mediaupload']           = 'Envoyez un fichier dans la catégorie actuelle. Pour créer des sous-catégories, préfixez en le nom du fichier séparées par un double-point, après avoir choisis le(s) fichier(s). Le(s) fichier(s) peuvent également être envoyé(s) par glisser-déposer (drag &amp; drop)';
 $lang['mediaextchange']        = 'Extension du fichier modifiée de .%s en .%s !';
 $lang['reference']             = 'Références pour';
 $lang['ref_inuse']             = 'Le fichier ne peut être effacé car il est toujours utilisé par les pages suivantes :';
@@ -210,10 +217,12 @@ $lang['diff_side']             = 'Côte à côte';
 $lang['diffprevrev']           = 'Révision précédente';
 $lang['diffnextrev']           = 'Prochaine révision';
 $lang['difflastrev']           = 'Dernière révision';
+$lang['diffbothprevrev']       = 'Les deux révisions précédentes';
+$lang['diffbothnextrev']       = 'Les deux révisions suivantes';
 $lang['line']                  = 'Ligne';
-$lang['breadcrumb']            = 'Piste';
-$lang['youarehere']            = 'Vous êtes ici';
-$lang['lastmod']               = 'Dernière modification';
+$lang['breadcrumb']            = 'Piste:';
+$lang['youarehere']            = 'Vous êtes ici:';
+$lang['lastmod']               = 'Dernière modification:';
 $lang['by']                    = 'par';
 $lang['deleted']               = 'supprimée';
 $lang['created']               = 'créée';
@@ -221,7 +230,7 @@ $lang['restored']              = 'ancienne révision (%s) restaurée';
 $lang['external_edit']         = 'modification externe';
 $lang['summary']               = 'Résumé';
 $lang['noflash']               = 'L\'<a href="http://www.adobe.com/products/flashplayer/">extension Adobe Flash</a> est nécessaire pour afficher ce contenu.';
-$lang['download']              = 'Télécharger un extrait';
+$lang['download']              = 'Télécharger cet extrait';
 $lang['tools']                 = 'Outils';
 $lang['user_tools']            = 'Outils pour utilisateurs';
 $lang['site_tools']            = 'Outils du site';
@@ -262,40 +271,38 @@ $lang['qb_sig']                = 'Insérer une signature';
 $lang['qb_smileys']            = 'Émoticones';
 $lang['qb_chars']              = 'Caractères spéciaux';
 $lang['upperns']               = 'Aller à la catégorie parente';
-$lang['admin_register']        = 'Ajouter un nouvel utilisateur';
 $lang['metaedit']              = 'Modifier les métadonnées';
 $lang['metasaveerr']           = 'Erreur lors de l\'enregistrement des métadonnées';
 $lang['metasaveok']            = 'Métadonnées enregistrées';
-$lang['img_title']             = 'Titre';
-$lang['img_caption']           = 'Légende';
-$lang['img_date']              = 'Date';
-$lang['img_fname']             = 'Nom de fichier';
-$lang['img_fsize']             = 'Taille';
-$lang['img_artist']            = 'Photographe';
-$lang['img_copyr']             = 'Copyright';
-$lang['img_format']            = 'Format';
-$lang['img_camera']            = 'Appareil photo';
-$lang['img_keywords']          = 'Mots-clés';
-$lang['img_width']             = 'Largeur';
-$lang['img_height']            = 'Hauteur';
-$lang['subscr_subscribe_success'] = '%s a été ajouté à la liste de souscription de %s';
-$lang['subscr_subscribe_error'] = 'Erreur à l\'ajout de %s à la liste de souscription de %s';
-$lang['subscr_subscribe_noaddress'] = 'Il n\'y a pas d\'adresse associée à votre identifiant, vous ne pouvez pas être ajouté à la liste de souscription';
-$lang['subscr_unsubscribe_success'] = '%s a été supprimé de la liste de souscription de %s';
-$lang['subscr_unsubscribe_error'] = 'Erreur au retrait de %s de la liste de souscription de %s';
-$lang['subscr_already_subscribed'] = '%s est déjà souscrit à %s';
-$lang['subscr_not_subscribed'] = '%s n\'est pas souscrit à %s';
-$lang['subscr_m_not_subscribed'] = 'Vous n\'avez pas souscrit pour l\'instant à la page actuelle ou à la catégorie';
-$lang['subscr_m_new_header']   = 'Ajouter une souscription';
-$lang['subscr_m_current_header'] = 'Souscriptions actives';
-$lang['subscr_m_unsubscribe']  = 'Annuler la souscription';
-$lang['subscr_m_subscribe']    = 'Souscrire';
+$lang['img_title']             = 'Titre:';
+$lang['img_caption']           = 'Légende:';
+$lang['img_date']              = 'Date:';
+$lang['img_fname']             = 'Nom de fichier:';
+$lang['img_fsize']             = 'Taille:';
+$lang['img_artist']            = 'Photographe:';
+$lang['img_copyr']             = 'Copyright:';
+$lang['img_format']            = 'Format:';
+$lang['img_camera']            = 'Appareil photo:';
+$lang['img_keywords']          = 'Mots-clés:';
+$lang['img_width']             = 'Largeur:';
+$lang['img_height']            = 'Hauteur:';
+$lang['subscr_subscribe_success'] = '%s a été ajouté à la liste des abonnés de %s';
+$lang['subscr_subscribe_error'] = 'Erreur à l\'ajout de %s à la liste des abonnés de %s';
+$lang['subscr_subscribe_noaddress'] = 'Il n\'y a pas d\'adresse associée à votre identifiant, vous ne pouvez pas être ajouté à la liste des abonnés.';
+$lang['subscr_unsubscribe_success'] = '%s a été supprimé de la liste des abonnés de %s';
+$lang['subscr_unsubscribe_error'] = 'Erreur au retrait de %s de la liste des abonnés de %s';
+$lang['subscr_already_subscribed'] = '%s est déjà abonné à %s';
+$lang['subscr_not_subscribed'] = '%s n\'est pas abonné à %s';
+$lang['subscr_m_not_subscribed'] = 'Vous n\'êtes pour l\'instant pas abonné à la page actuelle ou à la catégorie';
+$lang['subscr_m_new_header']   = 'Ajouter un abonnement';
+$lang['subscr_m_current_header'] = 'Abonnements actifs';
+$lang['subscr_m_unsubscribe']  = 'Annuler l\'abonnement';
+$lang['subscr_m_subscribe']    = 'S\'abonner';
 $lang['subscr_m_receive']      = 'Recevoir';
 $lang['subscr_style_every']    = 'Recevoir un courriel à chaque modification';
 $lang['subscr_style_digest']   = 'Courriel, tous les %.2f jours, résumant les modifications de chaque page';
 $lang['subscr_style_list']     = 'Liste des pages modifiées depuis le dernier courriel (tous les %.2f jours)';
 $lang['authtempfail']          = 'L\'authentification est temporairement indisponible. Si cela perdure, merci d\'en informer l\'administrateur du wiki.';
-$lang['authpwdexpire']         = 'Votre mot de passe expirera dans %d jours, vous devriez le changer bientôt.';
 $lang['i_chooselang']          = 'Choisissez votre langue';
 $lang['i_installer']           = 'Installateur DokuWiki';
 $lang['i_wikiname']            = 'Nom du wiki';
@@ -305,13 +312,14 @@ $lang['i_problems']            = 'L\'installateur a détecté les problèmes ind
 $lang['i_modified']            = 'Pour des raisons de sécurité, ce script ne fonctionne qu\'avec une installation neuve et non modifiée de DokuWiki. Vous devriez ré-extraire les fichiers depuis le paquet téléchargé ou consulter les <a href="http://dokuwiki.org/install">instructions d\'installation de DokuWiki</a>';
 $lang['i_funcna']              = 'La fonction PHP <code>%s</code> n\'est pas disponible. Peut-être que votre hébergeur web l\'a désactivée ?';
 $lang['i_phpver']              = 'Votre version de PHP (%s) est antérieure à la version requise (%s). Vous devez mettre à jour votre installation de PHP.';
+$lang['i_mbfuncoverload']      = 'Il faut désactiver mbstring.func_overload dans php.ini pour DokuWiki';
 $lang['i_permfail']            = '<code>%s</code> n\'est pas accessible en écriture pour DokuWiki. Vous devez corriger les autorisations de ce répertoire !';
 $lang['i_confexists']          = '<code>%s</code> existe déjà';
 $lang['i_writeerr']            = 'Impossible de créer <code>%s</code>. Vous devez vérifier les autorisations des répertoires/fichiers et créer le fichier manuellement.';
 $lang['i_badhash']             = 'dokuwiki.php non reconnu ou modifié (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - valeur interdite ou vide';
 $lang['i_success']             = 'L\'installation s\'est terminée avec succès. Vous pouvez maintenant supprimer le fichier « install.php ». Continuer avec <a href="doku.php?id=wiki:welcome">votre nouveau DokuWiki</a>.';
-$lang['i_failure']             = 'Des erreurs sont survenues lors de l\'écriture des fichiers de configuration. Il vous faudra les corriger manuellement avant de pouvoir utiliser <a href="doku.php">votre nouveau DokuWiki</a>.';
+$lang['i_failure']             = 'Des erreurs sont survenues lors de l\'écriture des fichiers de configuration. Il vous faudra les corriger manuellement avant de pouvoir utiliser <a href="doku.php?id=wiki:welcome">votre nouveau DokuWiki</a>.';
 $lang['i_policy']              = 'Politique de contrôle d\'accès initiale';
 $lang['i_pol0']                = 'Wiki ouvert (lecture, écriture, envoi de fichiers pour tout le monde)';
 $lang['i_pol1']                = 'Wiki public (lecture pour tout le monde, écriture et envoi de fichiers pour les utilisateurs enregistrés)';
@@ -354,7 +362,12 @@ $lang['media_perm_read']       = 'Désolé, vous n\'avez pas l\'autorisation de
 $lang['media_perm_upload']     = 'Désolé, vous n\'avez pas l\'autorisation d\'envoyer des fichiers.';
 $lang['media_update']          = 'Envoyer une nouvelle version';
 $lang['media_restore']         = 'Restaurer cette version';
-$lang['currentns']             = 'Namespace actuel';
+$lang['media_acl_warning']     = 'En raison des restrictions dans les ACL et de pages cachées, cette liste peut ne pas être complète.';
+$lang['currentns']             = 'Catégorie courante';
 $lang['searchresult']          = 'Résultat de la recherche';
 $lang['plainhtml']             = 'HTML brut';
 $lang['wikimarkup']            = 'Wiki balise';
+$lang['page_nonexist_rev']     = 'La page n\'existait pas le %s. Elle a été créée le <a href="%s">%s</a>.';
+$lang['unable_to_parse_date']  = 'Ne peut analyser le paramètre date "%s".';
+$lang['email_signature_text'] = 'Ce courriel a été généré par DokuWiki depuis
+@DOKUWIKIURL@';
