@@ -2,7 +2,7 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
  * @author Giorgio Vecchiocattivi <giorgio@vecchio.it>
  * @author Roberto Bolli [http://www.rbnet.it/]
  * @author Silvia Sargentoni <polinnia@tin.it>
@@ -17,6 +17,11 @@
  * @author snarchio@gmail.com
  * @author Edmondo Di Tucci <snarchio@gmail.com>
  * @author Claudio Lanconelli <lancos@libero.it>
+ * @author Mirko <malisan.mirko@gmail.com>
+ * @author Francesco <francesco.cavalli@hotmail.com>
+ * @author Fabio <fabioslurp@yahoo.it>
+ * @author Torpedo <dgtorpedo@gmail.com>
+ * @author Maurizio <mcannavo@katamail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -48,7 +53,6 @@ $lang['btn_update']            = 'Aggiorna';
 $lang['btn_delete']            = 'Elimina';
 $lang['btn_back']              = 'Indietro';
 $lang['btn_backlink']          = 'Puntano qui';
-$lang['btn_backtomedia']       = 'Torna alla selezione file';
 $lang['btn_subscribe']         = 'Sottoscrivi modifiche';
 $lang['btn_profile']           = 'Aggiorna profilo';
 $lang['btn_reset']             = 'Annulla';
@@ -61,7 +65,9 @@ $lang['btn_register']          = 'Registrazione';
 $lang['btn_apply']             = 'Applica';
 $lang['btn_media']             = 'Gestore Media';
 $lang['btn_deleteuser']        = 'Rimuovi il mio account';
-$lang['loggedinas']            = 'Collegato come';
+$lang['btn_img_backto']        = 'Torna a %s';
+$lang['btn_mediaManager']      = 'Guarda nel gestore media';
+$lang['loggedinas']            = 'Collegato come:';
 $lang['user']                  = 'Nome utente';
 $lang['pass']                  = 'Password';
 $lang['newpass']               = 'Nuova password';
@@ -76,10 +82,12 @@ $lang['badpassconfirm']        = 'La password è errata';
 $lang['minoredit']             = 'Modifiche minori';
 $lang['draftdate']             = 'Bozza salvata in automatico il';
 $lang['nosecedit']             = 'La pagina è stata modificata nel frattempo; è impossibile modificare solo la sezione scelta, quindi è stata caricata la pagina intera.';
+$lang['searchcreatepage']      = 'Se non hai trovato quello che cercavi, puoi creare una nuova pagina con questo titolo usando il pulsante \'\'Crea questa pagina\'\'.';
 $lang['regmissing']            = 'Devi riempire tutti i campi.';
 $lang['reguexists']            = 'Il nome utente inserito esiste già.';
 $lang['regsuccess']            = 'L\'utente è stato creato. La password è stata spedita via email.';
 $lang['regsuccess2']           = 'L\'utente è stato creato.';
+$lang['regfail']               = 'L\'utente non può essere creato.';
 $lang['regmailfail']           = 'Sembra che ci sia stato un errore nell\'invio della email. Contatta l\'amministratore!';
 $lang['regbadmail']            = 'L\'indirizzo email fornito sembra essere non valido - se pensi che ci sia un errore contatta l\'amministratore';
 $lang['regbadpass']            = 'Le due password inserite non coincidono, prova di nuovo.';
@@ -94,6 +102,7 @@ $lang['profdeleteuser']        = 'Elimina account';
 $lang['profdeleted']           = 'Il tuo account utente è stato rimosso da questa wiki';
 $lang['profconfdelete']        = 'Voglio rimuovere il mio account da questa wiki. <br/> Questa operazione non può essere annullata.';
 $lang['profconfdeletemissing'] = 'La check box di conferma non è selezionata';
+$lang['proffail']              = 'Il profilo utente non è stato aggiornato.';
 $lang['pwdforget']             = 'Hai dimenticato la password? Richiedine una nuova';
 $lang['resendna']              = 'Questo wiki non supporta l\'invio di nuove password.';
 $lang['resendpwd']             = 'Imposta nuova password per';
@@ -106,12 +115,12 @@ $lang['license']               = 'Ad eccezione da dove è diversamente indicato,
 $lang['licenseok']             = 'Nota: modificando questa pagina accetti di rilasciare il contenuto sotto la seguente licenza:';
 $lang['searchmedia']           = 'Cerca file di nome:';
 $lang['searchmedia_in']        = 'Cerca in %s';
-$lang['txt_upload']            = 'Seleziona un file da caricare';
-$lang['txt_filename']          = 'Carica come (opzionale)';
+$lang['txt_upload']            = 'Seleziona un file da caricare:';
+$lang['txt_filename']          = 'Carica come (opzionale):';
 $lang['txt_overwrt']           = 'Sovrascrivi file esistente';
 $lang['maxuploadsize']         = 'Upload max. %s per ogni file.';
-$lang['lockedby']              = 'Attualmente bloccato da';
-$lang['lockexpire']            = 'Il blocco scade alle';
+$lang['lockedby']              = 'Attualmente bloccato da:';
+$lang['lockexpire']            = 'Il blocco scade alle:';
 $lang['js']['willexpire']      = 'Il tuo blocco su questa pagina scadrà tra circa un minuto.\nPer evitare incongruenze usa il pulsante di anteprima per prolungare il periodo di blocco.';
 $lang['js']['notsavedyet']     = 'Le modifiche non salvate andranno perse.';
 $lang['js']['searchmedia']     = 'Cerca file';
@@ -146,6 +155,8 @@ $lang['js']['del_confirm']     = 'Eliminare veramente questa voce?';
 $lang['js']['restore_confirm'] = 'Vuoi davvero ripristinare questa versione?';
 $lang['js']['media_diff']      = 'Guarda le differenze:';
 $lang['js']['media_diff_both'] = 'Fianco a Fianco';
+$lang['js']['media_diff_opacity'] = 'Trasparire';
+$lang['js']['media_diff_portions'] = 'rubare';
 $lang['js']['media_select']    = 'Seleziona files..';
 $lang['js']['media_upload_btn'] = 'Upload';
 $lang['js']['media_done_btn']  = 'Fatto';
@@ -155,7 +166,6 @@ $lang['js']['media_overwrt']   = 'Sovrascrivi i file esistenti';
 $lang['rssfailed']             = 'Si è verificato un errore cercando questo feed: ';
 $lang['nothingfound']          = 'Nessun risultato trovato.';
 $lang['mediaselect']           = 'Selezione dei file';
-$lang['fileupload']            = 'File caricato';
 $lang['uploadsucc']            = 'Invio riuscito';
 $lang['uploadfail']            = 'Invio fallito. È possibile che si tratti di un problema di permessi.';
 $lang['uploadwrong']           = 'Invio rifiutato. Questa estensione di file non è ammessa';
@@ -189,10 +199,15 @@ $lang['difflink']              = 'Link a questa pagina di confronto';
 $lang['diff_type']             = 'Guarda le differenze:';
 $lang['diff_inline']           = 'In linea';
 $lang['diff_side']             = 'Fianco a Fianco';
+$lang['diffprevrev']           = 'Revisione precedente';
+$lang['diffnextrev']           = 'Prossima revisione';
+$lang['difflastrev']           = 'Ultima revisione';
+$lang['diffbothprevrev']       = 'Entrambe le parti precedenti la revisione';
+$lang['diffbothnextrev']       = 'Entrambe le parti successive la revisione';
 $lang['line']                  = 'Linea';
-$lang['breadcrumb']            = 'Traccia';
-$lang['youarehere']            = 'Ti trovi qui';
-$lang['lastmod']               = 'Ultima modifica';
+$lang['breadcrumb']            = 'Traccia:';
+$lang['youarehere']            = 'Ti trovi qui:';
+$lang['lastmod']               = 'Ultima modifica:';
 $lang['by']                    = 'da';
 $lang['deleted']               = 'eliminata';
 $lang['created']               = 'creata';
@@ -241,24 +256,21 @@ $lang['qb_sig']                = 'Inserisci la firma';
 $lang['qb_smileys']            = 'Smiley';
 $lang['qb_chars']              = 'Caratteri speciali';
 $lang['upperns']               = 'vai alla categoria principale';
-$lang['admin_register']        = 'Aggiungi un nuovo utente';
 $lang['metaedit']              = 'Modifica metadati';
 $lang['metasaveerr']           = 'Scrittura metadati fallita';
 $lang['metasaveok']            = 'Metadati salvati';
-$lang['img_backto']            = 'Torna a';
-$lang['img_title']             = 'Titolo';
-$lang['img_caption']           = 'Descrizione';
-$lang['img_date']              = 'Data';
-$lang['img_fname']             = 'Nome File';
-$lang['img_fsize']             = 'Dimensione';
-$lang['img_artist']            = 'Autore';
-$lang['img_copyr']             = 'Copyright';
-$lang['img_format']            = 'Formato';
-$lang['img_camera']            = 'Camera';
-$lang['img_keywords']          = 'Parole chiave';
-$lang['img_width']             = 'Larghezza';
-$lang['img_height']            = 'Altezza';
-$lang['img_manager']           = 'Guarda nel gestore media';
+$lang['img_title']             = 'Titolo:';
+$lang['img_caption']           = 'Descrizione:';
+$lang['img_date']              = 'Data:';
+$lang['img_fname']             = 'Nome File:';
+$lang['img_fsize']             = 'Dimensione:';
+$lang['img_artist']            = 'Autore:';
+$lang['img_copyr']             = 'Copyright:';
+$lang['img_format']            = 'Formato:';
+$lang['img_camera']            = 'Camera:';
+$lang['img_keywords']          = 'Parole chiave:';
+$lang['img_width']             = 'Larghezza:';
+$lang['img_height']            = 'Altezza:';
 $lang['subscr_subscribe_success'] = 'Aggiunto %s alla lista di sottoscrizioni %s';
 $lang['subscr_subscribe_error'] = 'Impossibile aggiungere %s alla lista di sottoscrizioni %s';
 $lang['subscr_subscribe_noaddress'] = 'Non esiste alcun indirizzo associato al tuo account, non puoi essere aggiunto alla lista di sottoscrizioni';
@@ -276,7 +288,6 @@ $lang['subscr_style_every']    = 'email per ogni modifica';
 $lang['subscr_style_digest']   = 'email di riassunto dei cambiamenti per ogni pagina (ogni %.2f giorni)';
 $lang['subscr_style_list']     = 'lista delle pagine cambiate dall\'ultima email (ogni %.2f giorni)';
 $lang['authtempfail']          = 'L\'autenticazione è temporaneamente non disponibile. Se questa situazione persiste, informa l\'amministratore di questo wiki.';
-$lang['authpwdexpire']         = 'La tua password scadrà in %d giorni, dovresti cambiarla quanto prima.';
 $lang['i_chooselang']          = 'Scegli la lingua';
 $lang['i_installer']           = 'Installazione di DokuWiki';
 $lang['i_wikiname']            = 'Nome Wiki';
@@ -288,6 +299,7 @@ Prova a estrarre di nuovo i file dal pacchetto scaricato oppure consulta le
 <a href="http://dokuwiki.org/install">istruzioni per l\'installazione di Dokuwiki</a>';
 $lang['i_funcna']              = 'La funzione PHP <code>%s</code> non è disponibile. Forse è stata disabilitata dal tuo provider per qualche motivo?';
 $lang['i_phpver']              = 'La versione di PHP <code>%s</code> è inferiore a quella richiesta <code>%s</code>. Devi aggiornare l\'installazione di PHP.';
+$lang['i_mbfuncoverload']      = 'mbstring.func_overload deve essere disabilitato in php.ini per eseguire DokuWiki.';
 $lang['i_permfail']            = 'DokuWiki non può scrivere <code>%s</code>. E\' necessario correggere i permessi per questa directory!';
 $lang['i_confexists']          = '<code>%s</code> esiste già';
 $lang['i_writeerr']            = 'Impossibile creare <code>%s</code>. E\' necessario verificare i permessi della directory o del file oppure creare il file manualmente.';
@@ -337,4 +349,12 @@ $lang['media_perm_read']       = 'Spiacente, non hai abbastanza privilegi per le
 $lang['media_perm_upload']     = 'Spiacente, non hai abbastanza privilegi per caricare files.';
 $lang['media_update']          = 'Carica nuova versione';
 $lang['media_restore']         = 'Ripristina questa versione';
+$lang['media_acl_warning']     = 'Questa lista potrebbe non essere completa a causa di restrizioni ACL e pagine nascoste.';
+$lang['currentns']             = 'Namespace corrente';
 $lang['searchresult']          = 'Risultati della ricerca';
+$lang['plainhtml']             = 'HTML';
+$lang['wikimarkup']            = 'Marcatura wiki';
+$lang['page_nonexist_rev']     = 'Pagina non esistente a %s. E\' stata creata successivamente a <a href="%s">%s</a>.';
+$lang['email_signature_text']       = 'Questa email è stata generata dal DokuWiki all\'indirizzo
+@DOKUWIKIURL@';
+$lang['unable_to_parse_date']  = 'Impossibile eseguire l\'analisi al parametro "%s".';
