@@ -42,7 +42,6 @@ $lang['btn_update']            = 'अद्ययावत';
 $lang['btn_delete']            = 'नष्ट';
 $lang['btn_back']              = 'मागॆ';
 $lang['btn_backlink']          = 'येथे काय जोडले आहे';
-$lang['btn_backtomedia']       = 'परत माध्यम फाइल निवडीकड़े';
 $lang['btn_subscribe']         = 'पृष्ठाच्या बदलांची पुरवणी (फीड) लावा ';
 $lang['btn_profile']           = 'प्रोफाइल अद्ययावत करा';
 $lang['btn_reset']             = 'रिसेट';
@@ -54,7 +53,7 @@ $lang['btn_revert']            = 'पुनर्स्थापन';
 $lang['btn_register']          = 'नोंदणी';
 $lang['btn_apply']             = 'लागू';
 $lang['btn_media']             = 'मिडिया व्यवस्थापक';
-$lang['loggedinas']            = 'लॉगिन नाव';
+$lang['loggedinas']            = 'लॉगिन नाव:';
 $lang['user']                  = 'वापरकर्ता';
 $lang['pass']                  = 'परवलीचा शब्द';
 $lang['newpass']               = 'नवीन परवलीचा शब्द';
@@ -68,6 +67,7 @@ $lang['badlogin']              = 'माफ़ करा, वापरकर्
 $lang['minoredit']             = 'छोटे बदल';
 $lang['draftdate']             = 'प्रत आपोआप सुरक्षित केल्याची तारीख';
 $lang['nosecedit']             = 'मध्यंतरीच्या काळात हे पृष्ठ बदलले आहे.विभागाची माहिती जुनी झाली होती. त्याऐवजी सबंध पृष्ठ परत लोड केले आहे.';
+$lang['searchcreatepage']      = 'जर तुमची शोधत असलेली गोष्ट तुम्हाला सापडली नाही, तर योग्य बटण वापरून तुम्ही शोधत असलेल्या गोष्टीविषयी तुम्ही एखादे पान निर्माण किंवा संपादित करू शकता.';
 $lang['regmissing']            = 'कृपया सर्व रकाने भरा.';
 $lang['reguexists']            = 'या नावाने सदस्याची नोंदणी झालेली आहे, कृपया दुसरे सदस्य नाव निवडा.';
 $lang['regsuccess']            = 'सदस्याची नोंदणी झाली आहे आणि परवलीचा शब्द इमेल केला आहे.';
@@ -93,8 +93,8 @@ $lang['license']               = 'विशिष्ठ नोंद केल
 $lang['licenseok']             = 'नोंद : हे पृष्ठ संपादित केल्यास तुम्ही तुमचे योगदान खालील लायसन्स अंतर्गत येइल : ';
 $lang['searchmedia']           = 'फाईल शोधा:';
 $lang['searchmedia_in']        = '%s मधे शोधा';
-$lang['txt_upload']            = 'अपलोड करण्याची फाइल निवडा';
-$lang['txt_filename']          = 'अपलोड उर्फ़ ( वैकल्पिक )';
+$lang['txt_upload']            = 'अपलोड करण्याची फाइल निवडा:';
+$lang['txt_filename']          = 'अपलोड उर्फ़ ( वैकल्पिक ):';
 $lang['txt_overwrt']           = 'अस्तित्वात असलेल्या फाइलवरच सुरक्षित करा.';
 $lang['lockedby']              = 'सध्या लॉक करणारा :';
 $lang['lockexpire']            = 'सध्या लॉक करणारा :';
@@ -139,7 +139,6 @@ $lang['js']['media_cancel']    = 'काढा';
 $lang['rssfailed']             = 'ही पुरवणी आणण्यात काही चूक झाली:';
 $lang['nothingfound']          = 'काही सापडला नाही.';
 $lang['mediaselect']           = 'दृकश्राव्य फाइल';
-$lang['fileupload']            = 'दृकश्राव्य फाइल अपलोड';
 $lang['uploadsucc']            = 'अपलोड यशस्वी';
 $lang['uploadfail']            = 'अपलोड अयशस्वी.कदाचित चुकीच्या परवानग्या असतील ?';
 $lang['uploadwrong']           = 'अपलोड नाकारण्यात आला. हे फाइल एक्सटेंशन अवैध आहे!';
@@ -174,9 +173,9 @@ $lang['diff_type']             = 'फरक बघू:';
 $lang['diff_inline']           = 'एका ओळीत';
 $lang['diff_side']             = 'बाजूबाजूला';
 $lang['line']                  = 'ओळ';
-$lang['breadcrumb']            = 'मागमूस';
-$lang['youarehere']            = 'तुम्ही इथे आहात';
-$lang['lastmod']               = 'सर्वात शेवटचा बदल';
+$lang['breadcrumb']            = 'मागमूस:';
+$lang['youarehere']            = 'तुम्ही इथे आहात:';
+$lang['lastmod']               = 'सर्वात शेवटचा बदल:';
 $lang['by']                    = 'द्वारा';
 $lang['deleted']               = 'काढून टाकले';
 $lang['created']               = 'निर्माण केले';
@@ -223,23 +222,22 @@ $lang['qb_sig']                = 'स्वाक्षरी टाका';
 $lang['qb_smileys']            = 'स्माइली';
 $lang['qb_chars']              = 'ख़ास चिन्ह';
 $lang['upperns']               = 'ह्यावरच्या नेमस्पेसकडे उडी मारा';
-$lang['admin_register']        = 'नवीन सदस्य';
 $lang['metaedit']              = 'मेटाडेटा बदला';
 $lang['metasaveerr']           = 'मेटाडेटा सुरक्षित झाला नाही';
 $lang['metasaveok']            = 'मेटाडेटा सुरक्षित झाला';
 $lang['btn_img_backto']            = 'परत जा %s';
-$lang['img_title']             = 'नाव';
-$lang['img_caption']           = 'टीप';
-$lang['img_date']              = 'तारीख';
-$lang['img_fname']             = 'फाइल नाव';
-$lang['img_fsize']             = 'साइझ';
-$lang['img_artist']            = 'फोटोग्राफर';
-$lang['img_copyr']             = 'कॉपीराइट';
-$lang['img_format']            = 'प्रकार';
-$lang['img_camera']            = 'कॅमेरा';
-$lang['img_keywords']          = 'मुख्य शब्द';
-$lang['img_width']             = 'रुंदी';
-$lang['img_height']            = 'उंची';
+$lang['img_title']             = 'नाव:';
+$lang['img_caption']           = 'टीप:';
+$lang['img_date']              = 'तारीख:';
+$lang['img_fname']             = 'फाइल नाव:';
+$lang['img_fsize']             = 'साइझ:';
+$lang['img_artist']            = 'फोटोग्राफर:';
+$lang['img_copyr']             = 'कॉपीराइट:';
+$lang['img_format']            = 'प्रकार:';
+$lang['img_camera']            = 'कॅमेरा:';
+$lang['img_keywords']          = 'मुख्य शब्द:';
+$lang['img_width']             = 'रुंदी:';
+$lang['img_height']            = 'उंची:';
 $lang['btn_mediaManager']           = 'मिडिया व्यवस्थापकात बघू';
 $lang['authtempfail']          = 'सदस्य अधिकृत करण्याची सुविधा सध्या चालू नाही. सतत हा मजकूर दिसल्यास कृपया तुमच्या विकीच्या व्यवस्थापकाशी सम्पर्क साधा.';
 $lang['i_chooselang']          = 'तुमची भाषा निवडा';
@@ -264,3 +262,5 @@ $lang['i_pol1']                = 'सार्वजनिक विकी ( स
 $lang['i_pol2']                = 'बंदिस्त विकी ( वाचन , लेखन व अपलोडची परवानगी फक्त नोंदणीकृत सदस्यांना ) ';
 $lang['i_retry']               = 'पुन्हा प्रयत्न';
 $lang['recent_global']         = 'तुम्ही सध्या <b>%s</b> या नेमस्पेस मधील बदल पाहात आहात.तुम्ही <a href="%s">पूर्ण विकी मधले बदल </a> सुद्धा पाहू शकता.';
+$lang['email_signature_text'] = 'हा ईमेल, येथील डॉक्युविकिद्वारा आपोआप तयार केला गेला आहे
+@DOKUWIKIURL@';
