@@ -2,7 +2,7 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
  * @author Yuri Pimenov <up@ftpsearch.lv>
  * @author Igor Tarasov <tigr@mail15.com>
  * @author Denis Simakov <akinoame1@gmail.com>
@@ -26,8 +26,16 @@
  * @author Erli Moen <evseev.jr@gmail.com>
  * @author Aleksandr Selivanov <alexgearbox@yandex.ru>
  * @author Владимир <id37736@yandex.ru>
+ * @author Igor Degraf <igordegraf@gmail.com>
+ * @author Type-kun <workwork-1@yandex.ru>
+ * @author Vitaly Filatenko <kot@hacktest.net>
+ * @author Alex P <alexander@lanos.co.uk>
+ * @author Nolf <m.kopachovets@gmail.com>
+ * @author Takumo <9206984@mail.ru>
+ * @author RainbowSpike <1@2.ru>
+ * @author dimsharav <dimsharav@gmail.com>
  */
-$lang['encoding']              = ' utf-8';
+$lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
 $lang['doublequoteopening']    = '«';
 $lang['doublequoteclosing']    = '»';
@@ -38,7 +46,7 @@ $lang['btn_edit']              = 'Править страницу';
 $lang['btn_source']            = 'Показать исходный текст';
 $lang['btn_show']              = 'Показать страницу';
 $lang['btn_create']            = 'Создать страницу';
-$lang['btn_search']            = 'Поиск';
+$lang['btn_search']            = 'Найти';
 $lang['btn_save']              = 'Сохранить';
 $lang['btn_preview']           = 'Просмотр';
 $lang['btn_top']               = 'Наверх';
@@ -57,10 +65,9 @@ $lang['btn_update']            = 'Обновить';
 $lang['btn_delete']            = 'Удалить';
 $lang['btn_back']              = 'Назад';
 $lang['btn_backlink']          = 'Ссылки сюда';
-$lang['btn_backtomedia']       = 'Вернуться к выбору медиафайла';
-$lang['btn_subscribe']         = 'Подписаться (все правки)';
+$lang['btn_subscribe']         = 'Управление подписками';
 $lang['btn_profile']           = 'Профиль';
-$lang['btn_reset']             = 'Сброс';
+$lang['btn_reset']             = 'Вернуть';
 $lang['btn_resendpwd']         = 'Установить новый пароль';
 $lang['btn_draft']             = 'Править черновик';
 $lang['btn_recover']           = 'Восстановить черновик';
@@ -86,73 +93,78 @@ $lang['badlogin']              = 'Извините, неверное имя по
 $lang['badpassconfirm']        = 'Простите, пароль неверный';
 $lang['minoredit']             = 'Небольшие изменения';
 $lang['draftdate']             = 'Черновик сохранён';
-$lang['nosecedit']             = 'За это время страница была изменена и информация о секции устарела. Загружена полная версия страницы.';
+$lang['nosecedit']             = 'За это время страница была изменена и информация о секции устарела. Загружена полная версия страницы.';
+$lang['searchcreatepage']      = 'Если вы не нашли то, что искали, вы можете создать новую страницу с именем, совпадающим с запросом. Чтобы сделать это, просто нажмите на кнопку «Создать страницу».';
 $lang['regmissing']            = 'Извините, вам следует заполнить все поля.';
 $lang['reguexists']            = 'Извините, пользователь с таким логином уже существует.';
-$lang['regsuccess']            = 'Пользователь создан; пароль выслан на адрес электронной почты.';
+$lang['regsuccess']            = 'Пользователь создан; пароль выслан на адрес электронной почты.';
 $lang['regsuccess2']           = 'Пользователь создан.';
-$lang['regmailfail']           = 'Похоже есть проблема с отправкой пароля по почте. Пожалуйста, сообщите об этом администратору.';
-$lang['regbadmail']            = 'Данный вами адрес электронной почты выглядит неправильным. Если вы считаете это ошибкой, сообщите администратору.';
-$lang['regbadpass']            = 'Два введённых пароля не идентичны. Пожалуйста, попробуйте ещё раз.';
+$lang['regfail']               = 'Пользователь не может быть создан.';
+$lang['regmailfail']           = 'Похоже есть проблема с отправкой пароля по почте. Пожалуйста, сообщите об этом администратору.';
+$lang['regbadmail']            = 'Данный вами адрес электронной почты выглядит неправильным. Если вы считаете это ошибкой, сообщите администратору.';
+$lang['regbadpass']            = 'Два введённых пароля не идентичны. Пожалуйста, попробуйте ещё раз.';
 $lang['regpwmail']             = 'Ваш пароль для системы «Докувики»';
 $lang['reghere']               = 'У вас ещё нет аккаунта? Зарегистрируйтесь';
 $lang['profna']                = 'Данная вики не поддерживает изменение профиля';
 $lang['profnochange']          = 'Изменений не было внесено, профиль не обновлён.';
 $lang['profnoempty']           = 'Логин и адрес электронной почты не могут быть пустыми.';
 $lang['profchanged']           = 'Профиль пользователя успешно обновлён.';
-$lang['profnodelete']          = 'Удалённый пользователь не может работать с этим документом';
+$lang['profnodelete']          = 'Удалённый пользователь не может работать с этим документом';
 $lang['profdeleteuser']        = 'Удалить аккаунт';
-$lang['profdeleted']           = 'Ваш аккаунт был удален из этой вики';
-$lang['profconfdelete']        = 'Я хочу удалить мой аккаунт из этой вики.<br />Это действие необратимо.';
-$lang['profconfdeletemissing'] = 'Флажок подтверждения не установлен';
+$lang['profdeleted']           = 'Ваш аккаунт был удалён из этой вики';
+$lang['profconfdelete']        = 'Я хочу удалить свой аккаунт из этой вики. <br />
+Это действие необратимо.';
+$lang['profconfdeletemissing'] = 'Флажок подтверждения не установлен';
+$lang['proffail']              = 'Профиль пользователя не был обновлен.';
 $lang['pwdforget']             = 'Забыли пароль? Получите новый';
-$lang['resendna']              = 'Данная вики не поддерживает повторную отправку пароля.';
+$lang['resendna']              = 'Данная вики не поддерживает повторную отправку пароля.';
 $lang['resendpwd']             = 'Установить новый пароль для';
 $lang['resendpwdmissing']      = 'Вы должны заполнить все поля формы.';
-$lang['resendpwdnouser']       = 'Пользователь с таким логином не обнаружен в нашей базе данных.';
-$lang['resendpwdbadauth']      = 'Извините, неверный код авторизации. Убедитесь, что вы полностью скопировали ссылку. ';
-$lang['resendpwdconfirm']      = 'Ссылка для подтверждения пароля была выслана по электронной почте. ';
-$lang['resendpwdsuccess']      = 'Ваш новый пароль был выслан по электронной почте.';
-$lang['license']               = 'За исключением случаев, когда указано иное, содержимое этой вики предоставляется на условиях следующей лицензии:';
-$lang['licenseok']             = 'Примечание: редактируя эту страницу, вы соглашаетесь на использование своего вклада на условиях следующей лицензии:';
-$lang['searchmedia']           = 'Поиск по имени файла:';
+$lang['resendpwdnouser']       = 'Пользователь с таким логином не обнаружен в нашей базе данных.';
+$lang['resendpwdbadauth']      = 'Извините, неверный код авторизации. Убедитесь, что вы полностью скопировали ссылку.';
+$lang['resendpwdconfirm']      = 'Ссылка для подтверждения пароля была выслана по электронной почте.';
+$lang['resendpwdsuccess']      = 'Ваш новый пароль был выслан по электронной почте.';
+$lang['license']               = 'За исключением случаев, когда указано иное, содержимое этой вики предоставляется на условиях следующей лицензии:';
+$lang['licenseok']             = 'Примечание: редактируя эту страницу, вы соглашаетесь на использование своего вклада на условиях следующей лицензии:';
+$lang['searchmedia']           = 'Поиск по имени файла';
 $lang['searchmedia_in']        = 'Поиск в %s';
-$lang['txt_upload']            = 'Выберите файл для загрузки';
-$lang['txt_filename']          = 'Введите имя файла в вики (необязательно)';
+$lang['txt_upload']            = 'Выберите файл для загрузки:';
+$lang['txt_filename']          = 'Введите имя файла в вики (необязательно):';
 $lang['txt_overwrt']           = 'Перезаписать существующий файл';
-$lang['maxuploadsize']         = 'Максимальный размер загружаемого файла %s';
-$lang['lockedby']              = 'В данный момент заблокирован';
+$lang['maxuploadsize']         = 'Макс. размер загружаемого файла %s';
+$lang['lockedby']              = 'В данный момент заблокировано пользователем';
 $lang['lockexpire']            = 'Блокировка истекает в';
-$lang['js']['willexpire']      = 'Ваша блокировка этой страницы на редактирование истекает в течение минуты.\nЧтобы предотвратить конфликты используйте кнопку «Просмотр» для сброса таймера блокировки.';
-$lang['js']['notsavedyet']     = 'Несохранённые изменения будут потеряны. Вы действительно хотите продолжить?';
+$lang['js']['willexpire']      = 'Ваша блокировка этой страницы на редактирование истекает в течение минуты.\nЧтобы предотвратить конфликты используйте кнопку «Просмотр» для сброса таймера блокировки.';
+$lang['js']['notsavedyet']     = 'Несохранённые изменения будут потеряны. Вы действительно хотите продолжить?';
 $lang['js']['searchmedia']     = 'Поиск файлов';
 $lang['js']['keepopen']        = 'Не закрывать окно после выбора';
 $lang['js']['hidedetails']     = 'Скрыть детали';
-$lang['js']['mediatitle']      = 'Настройки ссылок';
+$lang['js']['mediatitle']      = 'Настройка ссылки';
 $lang['js']['mediadisplay']    = 'Тип ссылки';
-$lang['js']['mediaalign']      = 'Выравнивание';
-$lang['js']['mediasize']       = 'Размер изображения';
-$lang['js']['mediatarget']     = 'Значение target ссылки';
+$lang['js']['mediaalign']      = 'Выравнивание
+';
+$lang['js']['mediasize']       = 'Размер';
+$lang['js']['mediatarget']     = 'Целевая ссылка';
 $lang['js']['mediaclose']      = 'Закрыть';
 $lang['js']['mediainsert']     = 'Вставить';
-$lang['js']['mediadisplayimg'] = 'Показывать изображение.';
-$lang['js']['mediadisplaylnk'] = 'Показывать только ссылку.';
+$lang['js']['mediadisplayimg'] = 'Показывать изображение';
+$lang['js']['mediadisplaylnk'] = 'Показывать только ссылку';
 $lang['js']['mediasmall']      = 'Малая версия';
 $lang['js']['mediamedium']     = 'Средняя версия';
 $lang['js']['medialarge']      = 'Крупная версия';
 $lang['js']['mediaoriginal']   = 'Исходная версия';
 $lang['js']['medialnk']        = 'Ссылка на подробности';
-$lang['js']['mediadirect']     = 'Прямая ссылка на оригинал';
+$lang['js']['mediadirect']     = 'Прямая ссылка на оригинал';
 $lang['js']['medianolnk']      = 'Без ссылки';
-$lang['js']['medianolink']     = 'Не давать ссылку на изображение';
-$lang['js']['medialeft']       = 'Выровнять изображение по левому краю.';
-$lang['js']['mediaright']      = 'Выровнять изображение по правому краю.';
-$lang['js']['mediacenter']     = 'Выровнять изображение по центру.';
-$lang['js']['medianoalign']    = 'Не выравнивать.';
-$lang['js']['nosmblinks']      = 'Ссылка на сетевые каталоги Windows работает только из MS Internet Explorer, но вы можете скопировать ссылку.';
+$lang['js']['medianolink']     = 'Не давать ссылку на изображение';
+$lang['js']['medialeft']       = 'Выровнять изображение по левому краю';
+$lang['js']['mediaright']      = 'Выровнять изображение по правому краю';
+$lang['js']['mediacenter']     = 'Выровнять изображение по центру';
+$lang['js']['medianoalign']    = 'Не выравнивать';
+$lang['js']['nosmblinks']      = 'Ссылка на сетевые каталоги Windows работает только из MS Internet Explorer, но вы можете скопировать ссылку.';
 $lang['js']['linkwiz']         = 'Мастер ссылок';
 $lang['js']['linkto']          = 'Ссылка на:';
-$lang['js']['del_confirm']     = 'Вы на самом деле желаете удалить выбранное?';
+$lang['js']['del_confirm']     = 'Вы на самом деле желаете удалить выбранное?';
 $lang['js']['restore_confirm'] = 'Действительно восстановить эту версию?';
 $lang['js']['media_diff']      = 'Просмотр отличий:';
 $lang['js']['media_diff_both'] = 'рядом';
@@ -167,7 +179,6 @@ $lang['js']['media_overwrt']   = 'Перезаписать существующ
 $lang['rssfailed']             = 'Произошла ошибка при получении следующей новостной ленты: ';
 $lang['nothingfound']          = 'Ничего не найдено.';
 $lang['mediaselect']           = 'Выбор медиафайла';
-$lang['fileupload']            = 'Загрузка медиафайла';
 $lang['uploadsucc']            = 'Загрузка произведена успешно';
 $lang['uploadfail']            = 'Загрузка не удалась. Возможно, проблемы с правами доступа?';
 $lang['uploadwrong']           = 'В загрузке отказано. Файлы с таким расширением запрещены. ';
@@ -175,43 +186,45 @@ $lang['uploadexist']           = 'Файл с таким именем сущес
 $lang['uploadbadcontent']      = 'Содержание файла не соответствует расширению %s.';
 $lang['uploadspam']            = 'Загрузка заблокирована спам-фильтром.';
 $lang['uploadxss']             = 'Загрузка заблокирована по соображениям безопасности.';
-$lang['uploadsize']            = 'Загруженный файл был слишком большой. (макс. %s)';
-$lang['deletesucc']            = 'Файл «%s» был удалён.';
-$lang['deletefail']            = 'Невозможно удалить файл «%s». Проверьте права доступа к файлу.';
-$lang['mediainuse']            = 'Файл «%s» не был удалён — файл всё ещё используется.';
+$lang['uploadsize']            = 'Загруженный файл был слишком большой. (Макс. %s)';
+$lang['deletesucc']            = 'Файл %s был удалён.';
+$lang['deletefail']            = 'Невозможно удалить файл %s. Проверьте права доступа к файлу.';
+$lang['mediainuse']            = 'Файл %s не был удалён — файл всё ещё используется.';
 $lang['namespaces']            = 'Пространства имён';
 $lang['mediafiles']            = 'Доступные файлы';
 $lang['accessdenied']          = 'Вы не можете просмотреть эту страницу.';
 $lang['mediausage']            = 'Для ссылки на этот файл используйте следующий синтаксис:';
 $lang['mediaview']             = 'Посмотреть исходный файл';
 $lang['mediaroot']             = 'корень';
-$lang['mediaupload']           = 'Здесь можно загрузить файл в текущий каталог («пространство имён»). Чтобы создать подкаталоги, добавьте их к началу имени файла («Загрузить как»). Имена подкаталогов разделяются двоеточиями. ';
-$lang['mediaextchange']        = 'Расширение изменилось: с .%s на .%s!';
+$lang['mediaupload']           = 'Здесь можно загрузить файл в текущий каталог («пространство имён»). Чтобы создать подкаталоги, добавьте их к началу имени файла («Загрузить как»). Имена подкаталогов разделяются двоеточиями.';
+$lang['mediaextchange']        = 'Расширение изменилось с .%s на .%s!';
 $lang['reference']             = 'Ссылки для';
-$lang['ref_inuse']             = 'Этот файл не может быть удалён, так как он используется на следующих страницах:';
-$lang['ref_hidden']            = 'Некоторые ссылки находятся на страницах, на чтение которых у вас нет прав доступа';
+$lang['ref_inuse']             = 'Этот файл не может быть удалён, так как он используется на следующих страницах:';
+$lang['ref_hidden']            = 'Некоторые ссылки находятся на страницах, на чтение которых у вас нет прав доступа';
 $lang['hits']                  = 'соответствий';
-$lang['quickhits']             = 'Соответствия в названиях страниц';
+$lang['quickhits']             = 'Подходящие страницы';
 $lang['toc']                   = 'Содержание';
 $lang['current']               = 'текущий';
 $lang['yours']                 = 'Ваша версия';
-$lang['diff']                  = 'показать отличия от текущей версии';
+$lang['diff']                  = 'Показать отличия от текущей версии';
 $lang['diff2']                 = 'Показать различия между ревизиями  ';
 $lang['difflink']              = 'Ссылка на это сравнение';
-$lang['diff_type']             = 'Посмотреть отличия';
-$lang['diff_inline']           = 'встроенный';
-$lang['diff_side']             = 'бок о бок';
+$lang['diff_type']             = 'Посмотреть различия';
+$lang['diff_inline']           = 'внутри текста';
+$lang['diff_side']             = 'двумя колонками';
 $lang['diffprevrev']           = 'Предыдущая версия';
-$lang['diffnextrev']           = 'Следущая версия';
+$lang['diffnextrev']           = 'Следующая версия';
 $lang['difflastrev']           = 'Последняя версия';
+$lang['diffbothprevrev']       = 'Предыдущая версия справа и слева';
+$lang['diffbothnextrev']       = 'Следующая версия справа и слева';
 $lang['line']                  = 'Строка';
-$lang['breadcrumb']            = 'Вы посетили';
-$lang['youarehere']            = 'Вы находитесь здесь';
-$lang['lastmod']               = 'Последние изменения';
+$lang['breadcrumb']            = 'Вы посетили:';
+$lang['youarehere']            = 'Вы находитесь здесь:';
+$lang['lastmod']               = 'Последние изменения:';
 $lang['by']                    = ' —';
 $lang['deleted']               = 'удалено';
 $lang['created']               = 'создано';
-$lang['restored']              = 'старая ревизия восстановлена (%s)';
+$lang['restored']              = 'старая версия восстановлена (%s)';
 $lang['external_edit']         = 'внешнее изменение';
 $lang['summary']               = 'Сводка изменений';
 $lang['noflash']               = 'Для просмотра этого содержимого требуется <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
@@ -256,22 +269,21 @@ $lang['qb_sig']                = 'Вставить подпись';
 $lang['qb_smileys']            = 'Смайлики';
 $lang['qb_chars']              = 'Специальные символы';
 $lang['upperns']               = 'Перейти в родительское пространство имён';
-$lang['admin_register']        = 'Добавить пользователя';
 $lang['metaedit']              = 'Править метаданные';
 $lang['metasaveerr']           = 'Ошибка записи метаданных';
 $lang['metasaveok']            = 'Метаданные сохранены';
-$lang['img_title']             = 'Название';
-$lang['img_caption']           = 'Подпись';
-$lang['img_date']              = 'Дата';
-$lang['img_fname']             = 'Имя файла';
-$lang['img_fsize']             = 'Размер';
-$lang['img_artist']            = 'Фотограф';
-$lang['img_copyr']             = 'Авторские права';
-$lang['img_format']            = 'Формат';
-$lang['img_camera']            = 'Модель';
-$lang['img_keywords']          = 'Ключевые слова';
-$lang['img_width']             = 'Ширина';
-$lang['img_height']            = 'Высота';
+$lang['img_title']             = 'Название:';
+$lang['img_caption']           = 'Подпись:';
+$lang['img_date']              = 'Дата:';
+$lang['img_fname']             = 'Имя файла:';
+$lang['img_fsize']             = 'Размер:';
+$lang['img_artist']            = 'Фотограф:';
+$lang['img_copyr']             = 'Авторские права:';
+$lang['img_format']            = 'Формат:';
+$lang['img_camera']            = 'Модель:';
+$lang['img_keywords']          = 'Ключевые слова:';
+$lang['img_width']             = 'Ширина:';
+$lang['img_height']            = 'Высота:';
 $lang['subscr_subscribe_success'] = 'Добавлен %s в подписку на %s';
 $lang['subscr_subscribe_error'] = 'Невозможно добавить %s в подписку на %s';
 $lang['subscr_subscribe_noaddress'] = 'Нет адреса электронной почты, сопоставленного с вашей учётной записью. Вы не можете подписаться на рассылку';
@@ -286,10 +298,9 @@ $lang['subscr_m_unsubscribe']  = 'Отменить подписку';
 $lang['subscr_m_subscribe']    = 'Подписаться';
 $lang['subscr_m_receive']      = 'Получить';
 $lang['subscr_style_every']    = 'уведомлять о каждом изменении';
-$lang['subscr_style_digest']   = 'информационное электронное письмо со списком изменений для каждой страницы (каждые %.2f дней)';
-$lang['subscr_style_list']     = 'список изменённых страниц со времени последнего отправленного электронного письма (каждые %.2f дней)';
+$lang['subscr_style_digest']   = 'информационное электронное письмо со списком изменений для каждой страницы (каждые %.2f дн.)';
+$lang['subscr_style_list']     = 'список изменённых страниц со времени последнего отправленного электронного письма (каждые %.2f дн.)';
 $lang['authtempfail']          = 'Аутентификация пользователей временно недоступна. Если проблема продолжается какое-то время, пожалуйста, сообщите об этом своему администратору вики.';
-$lang['authpwdexpire']         = 'Действие вашего пароля истекает через %d дней. Вы должны изменить его как можно скорее';
 $lang['i_chooselang']          = 'Выберите свой язык/Choose your language';
 $lang['i_installer']           = 'Установка «Докувики»';
 $lang['i_wikiname']            = 'Название вики';
@@ -301,16 +312,17 @@ $lang['i_modified']            = 'Из соображений безопасно
                                   <a href="http://www.dokuwiki.org/install">инструкции по установке «Докувики»</a>';
 $lang['i_funcna']              = 'Функция PHP <code>%s</code> недоступна. Может быть, она по какой-то причине заблокирована вашим хостером?';
 $lang['i_phpver']              = 'Ваша версия PHP (<code>%s</code>) ниже требуемой (<code>%s</code>). Вам необходимо обновить установленную версию PHP.';
+$lang['i_mbfuncoverload']      = 'Для запуска «Докувики» необходимо отключить параметр mbstring.func_overload в php.ini';
 $lang['i_permfail']            = '<code>%s</code> недоступна для записи «Докувики». Вам необходимо исправить системные права доступа для этой директории!';
 $lang['i_confexists']          = '<code>%s</code> уже существует';
 $lang['i_writeerr']            = 'Не удалось создать <code>%s</code>. Вам необходимо проверить системные права доступа к файлу и директориям, и создать файл вручную. ';
-$lang['i_badhash']             = 'dokuwiki.php не распознан или изменён (хэш=<code>%s</code>)';
+$lang['i_badhash']             = 'dokuwiki.php не распознан или изменён (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> — недопустимое или пустое значение';
 $lang['i_success']             = 'Конфигурация прошла успешно. Теперь вы можете удалить файл install.php. Переходите к
                                  <a href="doku.php?id=wiki:welcome">своей новой «Докувики»</a>.';
 $lang['i_failure']             = 'При записи в файлы конфигурации были обнаружены ошибки. Возможно, вам придётся исправить их вручную, прежде чем вы сможете использовать <a href="doku.php?id=wiki:welcome">свою новую «Докувики»</a>.';
 $lang['i_policy']              = 'Исходная политика прав доступа';
-$lang['i_pol0']                = 'Открытая вики (чтение, запись, закачка файлов для всех)';
+$lang['i_pol0']                = 'Открытая вики (чтение, запись, загрузка файлов для всех)';
 $lang['i_pol1']                = 'Общедоступная вики (чтение для всех, запись и загрузка файлов для зарегистрированных пользователей)';
 $lang['i_pol2']                = 'Закрытая вики (чтение, запись и загрузка файлов только для зарегистрированных пользователей)';
 $lang['i_allowreg']            = 'Разрешить пользователям самостоятельно регистрироваться';
@@ -321,15 +333,15 @@ $lang['i_pop_field']           = 'Пожалуйста, помогите нам
 $lang['i_pop_label']           = 'Отправлять раз в месяц анонимную пользовательскую информацию разработчикам «Докувики»';
 $lang['recent_global']         = 'Вы просматриваете изменения в пространстве имён <b>%s</b>. Вы можете также <a href="%s">просмотреть недавние изменения во всей вики</a>.';
 $lang['years']                 = '%d лет назад';
-$lang['months']                = '%d месяц(ев) назад';
+$lang['months']                = '%d месяц (-ев) назад';
 $lang['weeks']                 = '%d недель назад';
 $lang['days']                  = '%d дней назад';
-$lang['hours']                 = '%d час(ов) назад';
+$lang['hours']                 = '%d час (-ов) назад';
 $lang['minutes']               = '%d минут назад';
 $lang['seconds']               = '%d секунд назад';
 $lang['wordblock']             = 'Ваши изменения не сохранены, поскольку они содержат блокируемые слова (спам).';
 $lang['media_uploadtab']       = 'Загрузка';
-$lang['media_searchtab']       = 'Поиск';
+$lang['media_searchtab']       = 'Найти';
 $lang['media_file']            = 'Файл';
 $lang['media_viewtab']         = 'Просмотр';
 $lang['media_edittab']         = 'Правка';
@@ -340,8 +352,8 @@ $lang['media_sort_name']       = 'Сортировка по имени';
 $lang['media_sort_date']       = 'Сортировка по дате';
 $lang['media_namespaces']      = 'Выберите каталог';
 $lang['media_files']           = 'Файлы в %s';
-$lang['media_upload']          = 'Загрузка в пространство имён <strong>%s</strong>.';
-$lang['media_search']          = 'Поиск в пространстве имён <strong>%s</strong>.';
+$lang['media_upload']          = 'Загрузка в пространство имён %s';
+$lang['media_search']          = 'Поиск в пространстве имён %s';
 $lang['media_view']            = '%s';
 $lang['media_viewold']         = '%s в %s
 ';
@@ -352,7 +364,12 @@ $lang['media_perm_read']       = 'Извините, у вас недостато
 $lang['media_perm_upload']     = 'Извините, у вас недостаточно прав для загрузки файлов.';
 $lang['media_update']          = 'Загрузить новую версию';
 $lang['media_restore']         = 'Восстановить эту версию';
+$lang['media_acl_warning']     = 'Этот список может быть неполным из-за ограничений списков контроля доступа (ACL) и скрытых страниц.';
 $lang['currentns']             = 'Текущее пространство имён';
 $lang['searchresult']          = 'Результаты поиска';
 $lang['plainhtml']             = 'Простой HTML';
 $lang['wikimarkup']            = 'вики-разметка';
+$lang['page_nonexist_rev']     = 'Эта страница ещё не существовала %s. Она была создана <a href="%s">%s</a>.';
+$lang['unable_to_parse_date']  = 'Невозможно обработать параметр "%s".';
+$lang['email_signature_text'] = 'Это письмо создано «Докувики» с сайта
+@DOKUWIKIURL@';
