@@ -2,7 +2,7 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
  * @author Selim Farsakoğlu <farsakogluselim@yahoo.de>
  * @author Aydın Coşkuner <aydinweb@gmail.com>
  * @author Cihan Kahveci <kahvecicihan@gmail.com>
@@ -11,6 +11,9 @@
  * @author farukerdemoncel@gmail.com
  * @author Mustafa Aslan <maslan@hotmail.com>
  * @author huseyin can <huseyincan73@gmail.com>
+ * @author ilker rifat kapaç <irifat@gmail.com>
+ * @author İlker R. Kapaç <irifat@gmail.com>
+ * @author Mete Cuma <mcumax@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -42,7 +45,6 @@ $lang['btn_update']            = 'Güncelle';
 $lang['btn_delete']            = 'Sil';
 $lang['btn_back']              = 'Geri';
 $lang['btn_backlink']          = 'Geri linkler';
-$lang['btn_backtomedia']       = 'Çokluortam dosyası seçimine dön';
 $lang['btn_subscribe']         = 'Sayfa Değişikliklerini Bildir';
 $lang['btn_profile']           = 'Kullanıcı Bilgilerini Güncelle';
 $lang['btn_reset']             = 'Sıfırla';
@@ -55,7 +57,9 @@ $lang['btn_register']          = 'Kayıt ol';
 $lang['btn_apply']             = 'Uygula';
 $lang['btn_media']             = 'Çokluortam Yöneticisi';
 $lang['btn_deleteuser']        = 'Hesabımı Sil';
-$lang['loggedinas']            = 'Giriş ismi';
+$lang['btn_img_backto']        = 'Şuna dön: %s';
+$lang['btn_mediaManager']      = 'Ortam oynatıcısında göster';
+$lang['loggedinas']            = 'Giriş ismi:';
 $lang['user']                  = 'Kullanıcı ismi';
 $lang['pass']                  = 'Parola';
 $lang['newpass']               = 'Yeni Parola';
@@ -70,10 +74,12 @@ $lang['badpassconfirm']        = 'Üzgünüz, parolanız yanlış';
 $lang['minoredit']             = 'Küçük Değişiklikler';
 $lang['draftdate']             = 'Taslak şu saatte otomatik kaydedildi:';
 $lang['nosecedit']             = 'Sayfa yakın zamanda değiştirilmiştir, bölüm bilgisi eski kalmıştır. Bunun için bölüm yerine tüm sayfa yüklenmiştir.';
+$lang['searchcreatepage']      = 'Aradığınız şeyi bulamadıysanız, \'\'Sayfayı değiştir\'\' tuşuna tıklayarak girdiğiniz sorgu adıyla yeni bir sayfa oluşturabilirsiniz .';
 $lang['regmissing']            = 'Üzgünüz, tüm alanları doldurmalısınız.';
 $lang['reguexists']            = 'Üzgünüz, bu isime sahip bir kullanıcı zaten mevcut.';
 $lang['regsuccess']            = 'Kullanıcı oluşturuldu ve şifre e-posta adresine gönderildi.';
 $lang['regsuccess2']           = 'Kullanıcı oluşturuldu.';
+$lang['regfail']               = 'Kullanıcı oluşturulamadı.';
 $lang['regmailfail']           = 'Şifrenizi e-posta ile gönderirken bir hata oluşmuş gibi görünüyor. Lütfen yönetici ile temasa geçiniz!';
 $lang['regbadmail']            = 'Verilen e-posta adresi geçersiz gibi görünüyor - bunun bir hata olduğunu düşünüyorsanız yönetici ile temasa geçiniz.';
 $lang['regbadpass']            = 'Girilen parolalar aynı değil. Lütfen tekrar deneyiniz.';
@@ -88,6 +94,7 @@ $lang['profdeleteuser']        = 'Hesabı Sil';
 $lang['profdeleted']           = 'Bu wiki\'den hesabınız silindi';
 $lang['profconfdelete']        = 'Bu wiki\'den hesabımı silmek istiyorum. <br/>Bu işlem geri alınamaz';
 $lang['profconfdeletemissing'] = 'Onay kutusu işaretlenmedi';
+$lang['proffail']              = 'Kullanıcı bilgileri güncellenmedi.';
 $lang['pwdforget']             = 'Parolanızı mı unuttunuz? Yeni bir parola alın';
 $lang['resendna']              = 'Bu wiki parolayı tekrar göndermeyi desteklememektedir.';
 $lang['resendpwd']             = 'İçin yeni şifre belirle';
@@ -100,8 +107,8 @@ $lang['license']               = 'Aksi belirtilmediği halde, bu wikinin içeri
 $lang['licenseok']             = 'Not: Bu sayfayı değiştirerek yazınızın şu lisans ile yayınlanmasını kabul etmiş olacaksınız:';
 $lang['searchmedia']           = 'Dosya Adı Ara:';
 $lang['searchmedia_in']        = '%s içinde ara';
-$lang['txt_upload']            = 'Yüklenecek dosyayı seç';
-$lang['txt_filename']          = 'Dosya adı (zorunlu değil)';
+$lang['txt_upload']            = 'Yüklenecek dosyayı seç:';
+$lang['txt_filename']          = 'Dosya adı (zorunlu değil):';
 $lang['txt_overwrt']           = 'Mevcut dosyanın üstüne yaz';
 $lang['maxuploadsize']         = 'Yükleme dosya başına en fazla %s';
 $lang['lockedby']              = 'Şu an şunun tarafından kilitli:';
@@ -149,7 +156,6 @@ $lang['js']['media_overwrt']   = 'Var olan dosyaların üzerine yaz';
 $lang['rssfailed']             = 'Bu beslemeyi çekerken hata oluştu: ';
 $lang['nothingfound']          = 'Hiçbir şey yok.';
 $lang['mediaselect']           = 'Çokluortam dosyası seçimi';
-$lang['fileupload']            = 'Çokluortam dosyası yükleme';
 $lang['uploadsucc']            = 'Yükleme tamam';
 $lang['uploadfail']            = 'Yükleme başarısız. Yetki hatası olabilir!';
 $lang['uploadwrong']           = 'Yükleme engellendi. Bu dosya uzantısına izin verilmiyor!';
@@ -181,10 +187,17 @@ $lang['diff']                  = 'Kullanılan sürüm ile farkları göster';
 $lang['diff2']                 = 'Seçili sürümler arasındaki farkı göster';
 $lang['difflink']              = 'Karşılaştırma görünümüne bağlantı';
 $lang['diff_type']             = 'farklı görünüş';
+$lang['diff_inline']           = 'Satır içi';
+$lang['diff_side']             = 'Yan yana';
+$lang['diffprevrev']           = 'Önceki sürüm';
+$lang['diffnextrev']           = 'Sonraki sürüm';
+$lang['difflastrev']           = 'Son sürüm';
+$lang['diffbothprevrev']       = 'İki taraf da önceki sürüm';
+$lang['diffbothnextrev']       = 'İki taraf da sonraki sürüm';
 $lang['line']                  = 'Satır';
-$lang['breadcrumb']            = 'İz';
-$lang['youarehere']            = 'Buradasınız';
-$lang['lastmod']               = 'Son değiştirilme';
+$lang['breadcrumb']            = 'İz:';
+$lang['youarehere']            = 'Buradasınız:';
+$lang['lastmod']               = 'Son değiştirilme:';
 $lang['by']                    = 'Değiştiren:';
 $lang['deleted']               = 'silindi';
 $lang['created']               = 'oluşturuldu';
@@ -201,6 +214,7 @@ $lang['skip_to_content']       = 'Bağlanmak için kaydır';
 $lang['sidebar']               = 'kaydırma çubuğu';
 $lang['mail_newpage']          = 'sayfa eklenme:';
 $lang['mail_changed']          = 'sayfa değiştirilme:';
+$lang['mail_subscribe_list']   = 'isimalanındaki değişmiş sayfalar: ';
 $lang['mail_new_user']         = 'yeni kullanıcı';
 $lang['mail_upload']           = 'dosya yüklendi:';
 $lang['changes_type']          = 'görünüşü değiştir';
@@ -220,6 +234,8 @@ $lang['qb_h5']                 = '5. Seviye Başlık';
 $lang['qb_h']                  = 'Başlık';
 $lang['qb_hs']                 = 'Başlığı seç';
 $lang['qb_hplus']              = 'Daha yüksek başlık';
+$lang['qb_hminus']             = 'Daha Düşük Başlık';
+$lang['qb_hequal']             = 'Aynı Seviye Başlık';
 $lang['qb_link']               = 'İç Bağlantı';
 $lang['qb_extlink']            = 'Dış Bağlantı';
 $lang['qb_hr']                 = 'Yatay Çizgi';
@@ -229,31 +245,38 @@ $lang['qb_media']              = 'Resim ve başka dosyalar ekle';
 $lang['qb_sig']                = 'İmza Ekle';
 $lang['qb_smileys']            = 'Gülen Yüzler';
 $lang['qb_chars']              = 'Özel Karakterler';
-$lang['admin_register']        = 'Yeni kullanıcı ekle...';
+$lang['upperns']               = 'ebeveyn isimalanına atla';
 $lang['metaedit']              = 'Metaverileri Değiştir';
 $lang['metasaveerr']           = 'Metaveri yazma başarısız ';
 $lang['metasaveok']            = 'Metaveri kaydedildi';
-$lang['btn_img_backto']            = 'Şuna dön: %s';
-$lang['img_title']             = 'Başlık';
-$lang['img_caption']           = 'Serlevha';
-$lang['img_date']              = 'Tarih';
-$lang['img_fname']             = 'Dosya Adı';
-$lang['img_fsize']             = 'Boyut';
-$lang['img_artist']            = 'Fotoğrafçı';
-$lang['img_copyr']             = 'Telif Hakkı';
-$lang['img_format']            = 'Biçim';
-$lang['img_camera']            = 'Fotoğraf Makinası';
-$lang['img_keywords']          = 'Anahtar Sözcükler';
-$lang['img_width']             = 'Genişlik';
-$lang['img_height']            = 'Yükseklik';
-$lang['btn_mediaManager']           = 'Ortam oynatıcısında göster';
+$lang['img_title']             = 'Başlık:';
+$lang['img_caption']           = 'Serlevha:';
+$lang['img_date']              = 'Tarih:';
+$lang['img_fname']             = 'Dosya Adı:';
+$lang['img_fsize']             = 'Boyut:';
+$lang['img_artist']            = 'Fotoğrafçı:';
+$lang['img_copyr']             = 'Telif Hakkı:';
+$lang['img_format']            = 'Biçim:';
+$lang['img_camera']            = 'Fotoğraf Makinası:';
+$lang['img_keywords']          = 'Anahtar Sözcükler:';
+$lang['img_width']             = 'Genişlik:';
+$lang['img_height']            = 'Yükseklik:';
+$lang['subscr_subscribe_success'] = '%s,  %s için abonelik listesine eklendi.';
+$lang['subscr_subscribe_error'] = '%s, %s için abonelik listesine eklenirken hata ile karşılaşıldı.';
+$lang['subscr_subscribe_noaddress'] = 'Oturum bilginiz ile ilişkilendirilmiş bir adres olmadığı için abonelik listesine dahil olamazsınız.';
+$lang['subscr_unsubscribe_success'] = '%s,  %s için abonelik listesinden çıkarıldı.';
+$lang['subscr_unsubscribe_error'] = '%s, %s için abonelik listesinden çıkarılırken hata ile karşılaşıldı.';
+$lang['subscr_already_subscribed'] = '%s zaten %s listesine abone.';
+$lang['subscr_not_subscribed'] = '%s, %s listesine abone değil.';
+$lang['subscr_m_not_subscribed'] = 'Bu sayfa veya isim alanına (namespace) abone değilsiniz.  ';
 $lang['subscr_m_new_header']   = 'Üyelik ekle';
 $lang['subscr_m_current_header'] = 'Üyeliğini onayla';
 $lang['subscr_m_unsubscribe']  = 'Üyelik iptali';
 $lang['subscr_m_subscribe']    = 'Kayıt ol';
 $lang['subscr_m_receive']      = 'Al';
+$lang['subscr_style_every']    = 'her değişiklikte e-posta gönder';
+$lang['subscr_style_list']     = 'Son e-postadan bu yana değiştirilen sayfaların listesi (her %.2f gün)';
 $lang['authtempfail']          = 'Kullanıcı doğrulama geçici olarak yapılamıyor. Eğer bu durum devam ederse lütfen Wiki yöneticine haber veriniz.';
-$lang['authpwdexpire']         = 'Şifreniz %d gün sonra geçersiz hale gelecek, yakın bir zamanda değiştirmelisiniz.';
 $lang['i_chooselang']          = 'Dili seçiniz';
 $lang['i_installer']           = 'Dokuwiki Kurulum Sihirbazı';
 $lang['i_wikiname']            = 'Wiki Adı';
@@ -263,19 +286,24 @@ $lang['i_problems']            = 'Kurulum sihirbazı aşağıda gösterilen soru
 $lang['i_modified']            = 'Güzenlik sebebiyle bu script sadece yeni ve değiştirilmemiş bir Dokuwiki kurulumunda çalışır. Ya indirdiğiniz paketi yeniden açmalı ya da <a href="http://dokuwiki.org/install"> adresindeki Dokuwiki kurulum kılavuzu</a>na bakmalısınız.';
 $lang['i_funcna']              = '<code>%s</code> PHP fonksiyonu bulunmamaktadır. Barındırma(Hosting) hizmetinde bu özellik kapatılmış olabilir.';
 $lang['i_phpver']              = '<code>%s</code> PHP sürümü, gereken <code>%s</code>  sürümünden daha düşük. PHP kurulumunu yükseltmeniz gerekmektedir.';
+$lang['i_mbfuncoverload']      = 'DokuWiki\'nin çalışması için php.ini dosyasında mbstring.func_overload seçeneği kapalı (değeri 0) olarak ayarlanmalıdır.';
 $lang['i_permfail']            = '<code>%s</code> Dokuwiki tarafından yazılabilir değil. İzin ayarlarını bu klasör için düzeltmeniz gerekmektedir!';
 $lang['i_confexists']          = '<code>%s</code> zaten var';
 $lang['i_writeerr']            = '<code>%s</code> oluşturulamadı. Dosya/Klasör izin ayarlarını gözden geçirip dosyayı elle oluşturmalısınız.';
 $lang['i_badhash']             = 'dokuwiki.php tanınamadı ya da değiştirilmiş (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - Yanlış veya boş değer';
-$lang['i_success']             = 'Kurulum başarıyla tamamlandı. Şimdi install.php dosyasını silebilirsiniz. <a href="doku.php">Yeni DokuWikiniz</a>i kullanabilirsiniz.';
-$lang['i_failure']             = 'Ayar dosyalarını yazarken bazı hatalar oluştu. <a href="doku.php">Yeni DokuWikiniz</a>i kullanmadan önce bu hatalarınızı elle düzeltmeniz gerekebilir.';
+$lang['i_success']             = 'Kurulum başarıyla tamamlandı. Şimdi install.php dosyasını silebilirsiniz. <a href="doku.php?id=wiki:welcome">Yeni DokuWikiniz</a>i kullanabilirsiniz.';
+$lang['i_failure']             = 'Ayar dosyalarını yazarken bazı hatalar oluştu. <a href="doku.php?id=wiki:welcome">Yeni DokuWikiniz</a>i kullanmadan önce bu hatalarınızı elle düzeltmeniz gerekebilir.';
 $lang['i_policy']              = 'İlk ACL ayarı';
 $lang['i_pol0']                = 'Tamamen Açık Wiki (herkes okuyabilir, yazabilir ve dosya yükleyebilir)';
 $lang['i_pol1']                = 'Açık Wiki (herkes okuyabilir, ancak  sadece üye olanlar yazabilir ve dosya yükleyebilir)';
 $lang['i_pol2']                = 'Kapalı Wiki (sadece üye olanlar okuyabilir, yazabilir ve dosya yükleyebilir)';
+$lang['i_allowreg']            = 'Kullanıcıların kendi kendilerine üye olmalarına için ver';
 $lang['i_retry']               = 'Tekrar Dene';
 $lang['i_license']             = 'Lütfen içeriği hangi lisans altında yayınlamak istediğniizi belirtin:';
+$lang['i_license_none']        = 'Hiç bir lisans bilgisi gösterme';
+$lang['i_pop_field']           = 'Lütfen DokuWiki deneyimini geliştirmemizde, bize yardım edin:';
+$lang['i_pop_label']           = 'DokuWiki geliştiricilerine ayda bir, anonim kullanım bilgisini gönder';
 $lang['recent_global']         = '<b>%s</b> namespace\'i içerisinde yapılan değişiklikleri görüntülemektesiniz. Wiki\'deki tüm değişiklikleri de <a href="%s">bu adresten</a> görebilirsiniz. ';
 $lang['years']                 = '%d yıl önce';
 $lang['months']                = '%d ay önce';
@@ -295,12 +323,21 @@ $lang['media_list_thumbs']     = 'Küçük resimler';
 $lang['media_list_rows']       = 'Satırlar';
 $lang['media_sort_name']       = 'İsim';
 $lang['media_sort_date']       = 'Tarih';
+$lang['media_namespaces']      = 'İsimalanı seçin';
 $lang['media_files']           = '%s deki dosyalar';
 $lang['media_upload']          = '%s dizinine yükle';
 $lang['media_search']          = '%s dizininde ara';
 $lang['media_view']            = '%s';
 $lang['media_edit']            = 'Düzenle %s';
 $lang['media_history']         = 'Geçmiş %s';
+$lang['media_meta_edited']     = 'üstveri düzenlendi';
+$lang['media_perm_read']       = 'Özür dileriz, dosyaları okumak için yeterli haklara sahip değilsiniz.';
 $lang['media_perm_upload']     = 'Üzgünüm, karşıya dosya yükleme yetkiniz yok.';
 $lang['media_update']          = 'Yeni versiyonu yükleyin';
 $lang['media_restore']         = 'Bu sürümü eski haline getir';
+$lang['currentns']             = 'Geçerli isimalanı';
+$lang['searchresult']          = 'Arama Sonucu';
+$lang['plainhtml']             = 'Yalın HTML';
+$lang['wikimarkup']            = 'Wiki Biçimlendirmesi';
+$lang['email_signature_text'] = 'Bu e-posta aşağıdaki DokuWiki tarafından otomatik olarak oluşturulmuştur
+@DOKUWIKIURL@';
