@@ -2,7 +2,7 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
  * @author ZDYX <zhangduyixiong@gmail.com>
  * @author http://www.chinese-tools.com/tools/converter-tradsimp.html
  * @author George Sheraton <guxd@163.com>
@@ -23,6 +23,10 @@
  * @author Cupen <Cupenoruler@foxmail.com>
  * @author xiqingongzi <Xiqingongzi@Gmail.com>
  * @author qinghao <qingxianhao@gmail.com>
+ * @author Yuwei Sun <yuwei@hrz.tu-chemnitz.de>
+ * @author Errol <errol@hotmail.com>
+ * @author Garfield <garfield_550@outlook.com>
+ * @author JellyChen <451453325@qq.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -54,7 +58,6 @@ $lang['btn_update']            = '更新';
 $lang['btn_delete']            = '删除';
 $lang['btn_back']              = '返回';
 $lang['btn_backlink']          = '反向链接';
-$lang['btn_backtomedia']       = '返回到媒体文件选择工具';
 $lang['btn_subscribe']         = '订阅本页更改';
 $lang['btn_profile']           = '更新个人信息';
 $lang['btn_reset']             = '重设';
@@ -69,7 +72,7 @@ $lang['btn_media']             = '媒体管理器';
 $lang['btn_deleteuser']        = '移除我的账户';
 $lang['btn_img_backto']        = '返回到 %s';
 $lang['btn_mediaManager']      = '在媒体管理器中查看';
-$lang['loggedinas']            = '登录为';
+$lang['loggedinas']            = '登录为:';
 $lang['user']                  = '用户名';
 $lang['pass']                  = '密码';
 $lang['newpass']               = '请输入新密码';
@@ -84,10 +87,12 @@ $lang['badpassconfirm']        = '对不起，密码错误';
 $lang['minoredit']             = '细微修改';
 $lang['draftdate']             = '草稿自动保存于';
 $lang['nosecedit']             = '在您编辑期间本页刚被他人修改过，局部信息已过期，故载入全页。';
+$lang['searchcreatepage']      = '如果没有找到您想要的东西，您可以使用相应的按钮来创建或编辑该页面。';
 $lang['regmissing']            = '对不起，您必须填写所有的字段。';
 $lang['reguexists']            = '对不起，该用户名已经存在。';
 $lang['regsuccess']            = '新用户已建立，密码将通过电子邮件发送给您。';
 $lang['regsuccess2']           = '新用户已建立';
+$lang['regfail']               = '用户不能被创建。';
 $lang['regmailfail']           = '发送密码邮件时产生错误。请联系管理员！';
 $lang['regbadmail']            = '您输入的邮件地址有问题——如果您认为这是系统错误，请联系管理员。';
 $lang['regbadpass']            = '您输入的密码与系统产生的不符，请重试。';
@@ -102,6 +107,7 @@ $lang['profdeleteuser']        = '删除账号';
 $lang['profdeleted']           = '你的用户已经从这个 wiki 中删除';
 $lang['profconfdelete']        = '我希望删除我的账户。<br/>这项操作无法撤销。';
 $lang['profconfdeletemissing'] = '确认框未勾选';
+$lang['proffail']              = '用户设置没有更新。';
 $lang['pwdforget']             = '忘记密码？立即获取新密码';
 $lang['resendna']              = '本维基不支持二次发送密码。';
 $lang['resendpwd']             = '设置新密码用于';
@@ -114,12 +120,12 @@ $lang['license']               = '除额外注明的地方外，本维基上的
 $lang['licenseok']             = '当您选择开始编辑本页，即寓示你同意将你贡献的内容按下列许可协议发布：';
 $lang['searchmedia']           = '查找文件名：';
 $lang['searchmedia_in']        = '在%s中查找';
-$lang['txt_upload']            = '选择要上传的文件';
-$lang['txt_filename']          = '上传并重命名为（可选）';
+$lang['txt_upload']            = '选择要上传的文件:';
+$lang['txt_filename']          = '上传并重命名为（可选）:';
 $lang['txt_overwrt']           = '覆盖已存在的同名文件';
 $lang['maxuploadsize']         = '上传限制。每个文件 %s';
-$lang['lockedby']              = '目前已被下列人员锁定';
-$lang['lockexpire']            = '预计锁定解除于';
+$lang['lockedby']              = '目前已被下列人员锁定:';
+$lang['lockexpire']            = '预计锁定解除于:';
 $lang['js']['willexpire']      = '您对本页的独有编辑权将于一分钟之后解除。\n为了防止与其他人的编辑冲突，请使用预览按钮重设计时器。';
 $lang['js']['notsavedyet']     = '未保存的更改将丢失。
 真的要继续？';
@@ -166,7 +172,6 @@ $lang['js']['media_overwrt']   = '覆盖已存在的文件';
 $lang['rssfailed']             = '获取该 RSS 信息时产生错误：';
 $lang['nothingfound']          = '什么都没有找到。';
 $lang['mediaselect']           = '媒体文件';
-$lang['fileupload']            = '上传媒体文件';
 $lang['uploadsucc']            = '上传成功';
 $lang['uploadfail']            = '上传失败。也许是上传权限错误。';
 $lang['uploadwrong']           = '上传失败。该扩展名被禁止。';
@@ -203,10 +208,12 @@ $lang['diff_side']             = '并排显示';
 $lang['diffprevrev']           = '前一修订版';
 $lang['diffnextrev']           = '后一修订版';
 $lang['difflastrev']           = '上一修订版';
+$lang['diffbothprevrev']       = '两侧同时换到之前的修订记录';
+$lang['diffbothnextrev']       = '两侧同时换到之后的修订记录';
 $lang['line']                  = '行';
-$lang['breadcrumb']            = '您的足迹';
-$lang['youarehere']            = '您在这里';
-$lang['lastmod']               = '最后更改';
+$lang['breadcrumb']            = '您的足迹:';
+$lang['youarehere']            = '您在这里:';
+$lang['lastmod']               = '最后更改:';
 $lang['by']                    = '由';
 $lang['deleted']               = '移除';
 $lang['created']               = '创建';
@@ -255,22 +262,21 @@ $lang['qb_sig']                = '插入签名';
 $lang['qb_smileys']            = '表情符号';
 $lang['qb_chars']              = '特殊字符';
 $lang['upperns']               = '跳转到父级名空间';
-$lang['admin_register']        = '添加新用户';
 $lang['metaedit']              = '编辑元数据';
 $lang['metasaveerr']           = '写入元数据失败';
 $lang['metasaveok']            = '元数据已保存';
-$lang['img_title']             = '标题';
-$lang['img_caption']           = '说明';
-$lang['img_date']              = '日期';
-$lang['img_fname']             = '名称';
-$lang['img_fsize']             = '大小';
-$lang['img_artist']            = '摄影师';
-$lang['img_copyr']             = '版权';
-$lang['img_format']            = '格式';
-$lang['img_camera']            = '相机';
-$lang['img_keywords']          = '关键字';
-$lang['img_width']             = '宽度';
-$lang['img_height']            = '高度';
+$lang['img_title']             = '标题:';
+$lang['img_caption']           = '说明:';
+$lang['img_date']              = '日期:';
+$lang['img_fname']             = '名称:';
+$lang['img_fsize']             = '大小:';
+$lang['img_artist']            = '摄影师:';
+$lang['img_copyr']             = '版权:';
+$lang['img_format']            = '格式:';
+$lang['img_camera']            = '相机:';
+$lang['img_keywords']          = '关键字:';
+$lang['img_width']             = '宽度:';
+$lang['img_height']            = '高度:';
 $lang['subscr_subscribe_success'] = '添加 %s 到 %s 的订阅列表';
 $lang['subscr_subscribe_error'] = '添加 %s 到 %s 的订阅列表中出现错误';
 $lang['subscr_subscribe_noaddress'] = '没有与您登录信息相关联的地址，您无法被添加到订阅列表';
@@ -288,7 +294,6 @@ $lang['subscr_style_every']    = '对每次更改发送邮件';
 $lang['subscr_style_digest']   = '对每个页面发送更改的摘要邮件（每 %.2f 天）';
 $lang['subscr_style_list']     = '自上封邮件以来更改的页面的列表（每 %.2f 天）';
 $lang['authtempfail']          = '用户认证暂时无法使用。如果该状态一直存在，请通知维基管理员。';
-$lang['authpwdexpire']         = '您的密码将在 %d 天内过期，请尽快更改';
 $lang['i_chooselang']          = '选择您的语言';
 $lang['i_installer']           = 'DokuWiki 安装工具';
 $lang['i_wikiname']            = '维基名称';
@@ -300,6 +305,7 @@ $lang['i_modified']            = '由于安全上的考虑，该脚本只能用
                          <a href="http://dokuwiki.org/install">Dokuwiki 安装指南</a>';
 $lang['i_funcna']              = 'PHP 功能 <code>%s</code> 无法使用。也许您的服务器提供商因为某些原因禁用了它。';
 $lang['i_phpver']              = '您的 PHP 版本 <code>%s</code> 低于最低要求的 <code>%s</code>。您需要升级您的 PHP 版本。';
+$lang['i_mbfuncoverload']      = '为了运行DocuWiki，您必须在php.ini中禁用mbstring.func_overload。';
 $lang['i_permfail']            = 'DokuWiki 无法写入 <code>%s</code>。您需要修改该路径的权限设定！';
 $lang['i_confexists']          = '<code>%s</code> 已经存在';
 $lang['i_writeerr']            = '无法创建 <code>%s</code>。您需要检查该路径/文件的权限设定并手动创建该文件。';
@@ -351,7 +357,12 @@ $lang['media_perm_read']       = '抱歉，您没有足够权限读取这些文
 $lang['media_perm_upload']     = '抱歉，您没有足够权限来上传文件。';
 $lang['media_update']          = '上传新版本';
 $lang['media_restore']         = '恢复这个版本';
+$lang['media_acl_warning']     = '此列表可能不完全是由ACL限制和隐藏的页面。';
 $lang['currentns']             = '当前命名空间';
 $lang['searchresult']          = '搜索结果';
 $lang['plainhtml']             = '纯HTML';
 $lang['wikimarkup']            = 'Wiki Markup 语言';
+$lang['page_nonexist_rev']     = '页面在 %s 不存在。它曾创建于 <a href="%s">%s</a>。';
+$lang['unable_to_parse_date']  = '无法解析参数 "%s"。';
+$lang['email_signature_text']  = '本邮件由 DokuWiki 自动创建
+@DOKUWIKIURL@';
