@@ -27,7 +27,7 @@ if(!defined('MAILHEADER_EOL')) define('MAILHEADER_EOL',"\n");
  * Check if a given mail address is valid
  */
 if (!defined('RFC2822_ATEXT')) define('RFC2822_ATEXT',"0-9a-zA-Z!#$%&'*+/=?^_`{|}~-");
-if (!defined('PREG_PATTERN_VALID_EMAIL')) define('PREG_PATTERN_VALID_EMAIL', '['.RFC2822_ATEXT.']+(?:\.['.RFC2822_ATEXT.']+)*@(?i:[0-9a-z][0-9a-z-]*\.)+(?i:[a-z]{2,4}|museum|travel)');
+if (!defined('PREG_PATTERN_VALID_EMAIL')) define('PREG_PATTERN_VALID_EMAIL', '['.RFC2822_ATEXT.']+(?:\.['.RFC2822_ATEXT.']+)*@(?i:[0-9a-z][0-9a-z-]*\.)+(?i:[a-z]{2,63})');
 
 /**
  * Prepare mailfrom replacement patterns
@@ -40,6 +40,8 @@ if (!defined('PREG_PATTERN_VALID_EMAIL')) define('PREG_PATTERN_VALID_EMAIL', '['
 function mail_setup(){
     global $conf;
     global $USERINFO;
+    /** @var Input $INPUT */
+    global $INPUT;
 
     // auto constructed address
     $host = @parse_url(DOKU_URL,PHP_URL_HOST);
@@ -53,11 +55,8 @@ function mail_setup(){
         $replace['@MAIL@'] = $noreply;
     }
 
-    if(!empty($_SERVER['REMOTE_USER'])){
-        $replace['@USER@'] = $_SERVER['REMOTE_USER'];
-    }else{
-        $replace['@USER@'] = 'noreply';
-    }
+    // use 'noreply' if no user
+    $replace['@USER@'] = $INPUT->server->str('REMOTE_USER', 'noreply', true);
 
     if(!empty($USERINFO['name'])){
         $replace['@NAME@'] = $USERINFO['name'];
@@ -97,15 +96,23 @@ function mail_setup(){
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  * @see    mail()
+ *
+ * @deprecated User the Mailer:: class instead
  */
 function mail_send($to, $subject, $body, $from='', $cc='', $bcc='', $headers=null, $params=null){
-
+    dbg_deprecated('class Mailer::');
     $message = compact('to','subject','body','from','cc','bcc','headers','params');
     return trigger_event('MAIL_MESSAGE_SEND',$message,'_mail_send_action');
 }
 
+/**
+ * @param $data
+ * @return bool
+ *
+ * @deprecated User the Mailer:: class instead
+ */
 function _mail_send_action($data) {
-
+    dbg_deprecated('class Mailer::');
     // retrieve parameters from event data, $to, $subject, $body, $from, $cc, $bcc, $headers, $params
     $to = $data['to'];
     $subject = $data['subject'];
@@ -178,8 +185,11 @@ function _mail_send_action($data) {
  * @param string  $string Multiple adresses separated by commas
  * @param string  $header Name of the header (To,Bcc,Cc,...)
  * @param boolean $names  Allow named Recipients?
+ *
+ * @deprecated User the Mailer:: class instead
  */
 function mail_encode_address($string,$header='',$names=true){
+    dbg_deprecated('class Mailer::');
     $headers = '';
     $parts = explode(',',$string);
     foreach ($parts as $part){
@@ -267,7 +277,7 @@ function mail_isvalid($email){
  * Quoted printable encoding
  *
  * @author umu <umuAThrz.tu-chemnitz.de>
- * @link   http://www.php.net/manual/en/function.imap-8bit.php#61216
+ * @link   http://php.net/manual/en/function.imap-8bit.php#61216
  */
 function mail_quotedprintable_encode($sText,$maxlen=74,$bEmulate_imap_8bit=true) {
     // split text into lines
