@@ -44,5 +44,24 @@ foreach (glob('*.png') as $img) {
 ?>
 </div>
 
+<br style="clear: left" />
+
+<div class="white box">
+    <?php
+    foreach (glob('32x32/*.png') as $img) {
+        echo '<img src="'.$img.'" alt="'.$img.'" title="'.$img.'" /> ';
+    }
+    ?>
+</div>
+
+<div class="black box">
+    <?php
+    foreach (glob('32x32/*.png') as $img) {
+        echo '<img src="'.$img.'" alt="'.$img.'" title="'.$img.'" /> ';
+    }
+    ?>
+</div>
+
+
 </body>
 </html>
