@@ -13,8 +13,8 @@
  * @author Volker Bödker <volker@boedker.de>
  */
 $lang['admin_acl']             = 'Zugangsverwaltung';
-$lang['acl_group']             = 'Gruppe';
-$lang['acl_user']              = 'Benutzer';
+$lang['acl_group']             = 'Gruppe:';
+$lang['acl_user']              = 'Benutzer:';
 $lang['acl_perms']             = 'Rechte für';
 $lang['page']                  = 'Seite';
 $lang['namespace']             = 'Namensraum';
