@@ -1,8 +1,8 @@
 <?php
+
 /**
- * German language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
  * @author Andreas Gohr <andi@splitbrain.org>
  * @author Michael Klier <chi@chimeric.de>
  * @author Leo Moll <leo@yeasoft.com>
@@ -18,6 +18,7 @@
  * @author Pierre Corell <info@joomla-praxis.de>
  * @author Matthias Schulte <dokuwiki@lupo49.de>
  * @author Mateng Schimmerlos <mateng@firemail.de>
+ * @author Anika Henke <anika@selfthinker.org>
  */
 $lang['menu']                  = 'Konfiguration';
 $lang['error']                 = 'Die Einstellungen wurden wegen einer fehlerhaften Eingabe nicht gespeichert.<br /> Bitte überprüfen sie die rot umrandeten Eingaben und speichern Sie erneut.';
@@ -41,33 +42,34 @@ $lang['_links']                = 'Links';
 $lang['_media']                = 'Medien';
 $lang['_notifications']        = 'Benachrichtigung';
 $lang['_syndication']          = 'Syndication (RSS)';
-$lang['_advanced']             = 'Erweitertet';
+$lang['_advanced']             = 'Erweitert';
 $lang['_network']              = 'Netzwerk';
 $lang['_msg_setting_undefined'] = 'Keine Konfigurationsmetadaten.';
 $lang['_msg_setting_no_class'] = 'Keine Konfigurationsklasse.';
 $lang['_msg_setting_no_default'] = 'Kein Standardwert.';
-$lang['fmode']                 = 'Berechtigungen für neue Dateien';
-$lang['dmode']                 = 'Berechtigungen für neue Verzeichnisse';
-$lang['lang']                  = 'Sprache';
-$lang['basedir']               = 'Installationsverzeichnis';
-$lang['baseurl']               = 'Installationspfad (URL)';
-$lang['savedir']               = 'Speicherverzeichnis';
-$lang['cookiedir']             = 'Cookiepfad. Frei lassen, um den gleichen Pfad wie "baseurl" zu benutzen.';
-$lang['start']                 = 'Startseitenname';
 $lang['title']                 = 'Titel des Wikis';
+$lang['start']                 = 'Startseitenname';
+$lang['lang']                  = 'Sprache';
 $lang['template']              = 'Designvorlage (Template)';
 $lang['tagline']               = 'Tag-Linie (nur, wenn vom Template unterstützt)';
 $lang['sidebar']               = 'Name der Sidebar-Seite (nur, wenn vom Template unterstützt), ein leeres Feld deaktiviert die Sidebar';
 $lang['license']               = 'Unter welcher Lizenz sollen Ihre Inhalte veröffentlicht werden?';
-$lang['fullpath']              = 'Den kompletten Dateipfad im Footer anzeigen';
+$lang['savedir']               = 'Speicherverzeichnis';
+$lang['basedir']               = 'Installationsverzeichnis';
+$lang['baseurl']               = 'Installationspfad (URL)';
+$lang['cookiedir']             = 'Cookiepfad. Frei lassen, um den gleichen Pfad wie "baseurl" zu benutzen.';
+$lang['dmode']                 = 'Berechtigungen für neue Verzeichnisse';
+$lang['fmode']                 = 'Berechtigungen für neue Dateien';
+$lang['allowdebug']            = 'Debug-Ausgaben erlauben <b>Abschalten wenn nicht benötigt!</b>';
 $lang['recent']                = 'Anzahl der Einträge in der Änderungsliste';
+$lang['recent_days']           = 'Wie viele letzte Änderungen sollen einsehbar bleiben? (Tage)';
 $lang['breadcrumbs']           = 'Anzahl der Einträge im "Krümelpfad"';
 $lang['youarehere']            = 'Hierarchische Pfadnavigation verwenden';
+$lang['fullpath']              = 'Den kompletten Dateipfad im Footer anzeigen';
 $lang['typography']            = 'Typographische Ersetzungen';
-$lang['htmlok']                = 'HTML erlauben';
-$lang['phpok']                 = 'PHP erlauben';
-$lang['dformat']               = 'Datumsformat (Siehe PHP <a href="http://www.php.net/strftime">strftime</a> Funktion)';
+$lang['dformat']               = 'Datumsformat (Siehe PHP <a href="http://php.net/strftime">strftime</a> Funktion)';
 $lang['signature']             = 'Signatur';
+$lang['showuseras']            = 'Was angezeigt werden soll, wenn der Benutzer, der zuletzt eine Seite bearbeitet hat, angezeigt wird';
 $lang['toptoclevel']           = 'Inhaltsverzeichnis bei dieser Überschriftengröße beginnen';
 $lang['tocminheads']           = 'Mindestanzahl der Überschriften die entscheidet, ob ein Inhaltsverzeichnis erscheinen soll';
 $lang['maxtoclevel']           = 'Maximale Überschriftengröße für Inhaltsverzeichnis';
@@ -75,15 +77,8 @@ $lang['maxseclevel']           = 'Abschnitte bis zu dieser Stufe einzeln editier
 $lang['camelcase']             = 'CamelCase-Verlinkungen verwenden';
 $lang['deaccent']              = 'Seitennamen bereinigen';
 $lang['useheading']            = 'Erste Überschrift als Seitennamen verwenden';
-$lang['refcheck']              = 'Auf Verwendung beim Löschen von Media-Dateien testen';
-$lang['allowdebug']            = 'Debug-Ausgaben erlauben <b>Abschalten wenn nicht benötigt!</b>';
-$lang['mediarevisions']        = 'Media-Revisionen (ältere Versionen) aktivieren?';
-$lang['usewordblock']          = 'Spam-Blocking benutzen';
-$lang['indexdelay']            = 'Zeit bevor Suchmaschinenindexierung erlaubt ist';
-$lang['relnofollow']           = 'rel="nofollow" verwenden';
-$lang['mailguard']             = 'E-Mail-Adressen schützen';
-$lang['iexssprotect']          = 'Hochgeladene Dateien auf bösartigen JavaScript- und HTML-Code untersuchen';
-$lang['showuseras']            = 'Was angezeigt werden soll, wenn der Benutzer, der zuletzt eine Seite bearbeitet hat, angezeigt wird';
+$lang['sneaky_index']          = 'Standardmäßig zeigt DokuWiki alle Namensräume in der Übersicht. Wenn diese Option aktiviert wird, werden alle Namensräume, für die der Benutzer keine Lese-Rechte hat, nicht angezeigt. Dies kann unter Umständen dazu führen, das lesbare Unter-Namensräume nicht angezeigt werden und macht die Übersicht evtl. unbrauchbar in Kombination mit bestimmten ACL Einstellungen.';
+$lang['hidepages']             = 'Seiten verstecken (Regulärer Ausdruck)';
 $lang['useacl']                = 'Zugangskontrolle verwenden';
 $lang['autopasswd']            = 'Passwort automatisch generieren';
 $lang['authtype']              = 'Authentifizierungsmechanismus';
@@ -92,63 +87,70 @@ $lang['defaultgroup']          = 'Standardgruppe';
 $lang['superuser']             = 'Administrator - Eine Gruppe oder Benutzer mit vollem Zugriff auf alle Seiten und Administrationswerkzeuge.';
 $lang['manager']               = 'Manager - Eine Gruppe oder Benutzer mit Zugriff auf einige Administrationswerkzeuge.';
 $lang['profileconfirm']        = 'Profiländerung nur nach Passwortbestätigung';
+$lang['rememberme']            = 'Permanente Login-Cookies erlauben (Auf diesem Computer eingeloggt bleiben)';
 $lang['disableactions']        = 'DokuWiki-Aktionen deaktivieren';
 $lang['disableactions_check']  = 'Check';
 $lang['disableactions_subscription'] = 'Seiten-Abonnements';
 $lang['disableactions_wikicode'] = 'Quelltext betrachten/exportieren';
 $lang['disableactions_profile_delete'] = 'Eigenes Benutzerprofil löschen';
 $lang['disableactions_other']  = 'Andere Aktionen (durch Komma getrennt)';
-$lang['sneaky_index']          = 'Standardmäßig zeigt DokuWiki alle Namensräume in der Übersicht. Wenn diese Option aktiviert wird, werden alle Namensräume, für die der Benutzer keine Lese-Rechte hat, nicht angezeigt. Dies kann unter Umständen dazu führen, das lesbare Unter-Namensräume nicht angezeigt werden und macht die Übersicht evtl. unbrauchbar in Kombination mit bestimmten ACL Einstellungen.';
+$lang['disableactions_rss']    = 'XML-Syndikation (RSS)';
 $lang['auth_security_timeout'] = 'Authentifikations-Timeout (Sekunden)';
 $lang['securecookie']          = 'Sollen Cookies, die via HTTPS gesetzt wurden nur per HTTPS versendet werden? Deaktivieren Sie diese Option, wenn nur der Login Ihres Wikis mit SSL gesichert ist, aber das Betrachten des Wikis ungesichert geschieht.';
 $lang['remote']                = 'Aktiviert den externen API-Zugang. Diese Option erlaubt es externen Anwendungen von außen auf die XML-RPC-Schnittstelle oder anderweitigen Schnittstellen zu zugreifen.';
 $lang['remoteuser']            = 'Zugriff auf die externen Schnittstellen durch kommaseparierte Angabe von Benutzern oder Gruppen einschränken. Ein leeres Feld erlaubt Zugriff für jeden.';
-$lang['updatecheck']           = 'Automatisch auf Updates und Sicherheitswarnungen prüfen? DokuWiki muss sich dafür mit update.dokuwiki.org verbinden.';
-$lang['userewrite']            = 'URL rewriting';
-$lang['useslash']              = 'Schrägstrich (/) als Namensraumtrenner in URLs verwenden';
+$lang['usewordblock']          = 'Spam-Blocking benutzen';
+$lang['relnofollow']           = 'rel="nofollow" verwenden';
+$lang['indexdelay']            = 'Zeit bevor Suchmaschinenindexierung erlaubt ist';
+$lang['mailguard']             = 'E-Mail-Adressen schützen';
+$lang['iexssprotect']          = 'Hochgeladene Dateien auf bösartigen JavaScript- und HTML-Code untersuchen';
 $lang['usedraft']              = 'Während des Bearbeitens automatisch Zwischenentwürfe speichern';
-$lang['sepchar']               = 'Worttrenner für Seitennamen in URLs';
-$lang['canonical']             = 'Immer Links mit vollständigen URLs erzeugen';
-$lang['fnencode']              = 'Methode um nicht-ASCII Dateinamen zu kodieren.';
-$lang['autoplural']            = 'Bei Links automatisch nach vorhandenen Pluralformen suchen';
-$lang['compression']           = 'Komprimierungsmethode für alte Seitenrevisionen';
-$lang['cachetime']             = 'Maximale Cachespeicherung (Sekunden)';
+$lang['htmlok']                = 'HTML erlauben';
+$lang['phpok']                 = 'PHP erlauben';
 $lang['locktime']              = 'Maximales Alter für Seitensperren (Sekunden)';
-$lang['fetchsize']             = 'Maximale Größe (in Bytes), die fetch.php von extern herunterladen darf';
-$lang['notify']                = 'Änderungsmitteilungen an diese E-Mail-Adresse versenden';
-$lang['registernotify']        = 'Information über neu registrierte Benutzer an diese E-Mail-Adresse senden';
-$lang['mailfrom']              = 'Absender-E-Mail-Adresse für automatische Mails';
-$lang['mailprefix']            = 'Präfix für E-Mail-Betreff beim automatischen Versand von Benachrichtigungen';
-$lang['htmlmail']              = 'Versendet optisch angenehmere, aber größere E-Mails im HTML-Format (multipart). Deaktivieren, um Text-Mails zu versenden.';
-$lang['gzip_output']           = 'Seiten mit gzip komprimiert ausliefern';
-$lang['gdlib']                 = 'GD Lib Version';
-$lang['im_convert']            = 'Pfad zum ImageMagicks-Konvertierwerkzeug';
-$lang['jpg_quality']           = 'JPEG Kompressionsqualität (0-100)';
-$lang['subscribers']           = 'E-Mail-Abos zulassen';
-$lang['subscribe_time']        = 'Zeit nach der Zusammenfassungs- und Änderungslisten-E-Mails verschickt werden; Dieser Wert sollte kleiner als die in recent_days konfigurierte Zeit sein.';
-$lang['compress']              = 'JavaScript und Stylesheets komprimieren';
-$lang['cssdatauri']            = 'Größe in Bytes, bis zu der Bilder in CSS-Dateien referenziert werden können, um HTTP-Anfragen zu minimieren. Diese Technik funktioniert nicht im IE 7 und älter!  Empfohlene Einstellung: <code>400</code> to <code>600</code> Bytes. Setzen Sie die Einstellung auf <code>0</code> um die Funktion zu deaktivieren.';
-$lang['hidepages']             = 'Seiten verstecken (Regulärer Ausdruck)';
-$lang['send404']               = 'Bei nicht vorhandenen Seiten mit 404 Fehlercode antworten';
-$lang['sitemap']               = 'Google Sitemap erzeugen (Tage)';
-$lang['broken_iua']            = 'Falls die Funktion ignore_user_abort auf Ihrem System nicht funktioniert, könnte der Such-Index nicht funktionieren. IIS+PHP/CGI ist bekannt dafür. Siehe auch <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a>.';
-$lang['xsendfile']             = 'Den X-Sendfile-Header nutzen, um Dateien direkt vom Webserver ausliefern zu lassen? Ihr Webserver muss dies unterstützen!';
-$lang['renderer_xhtml']        = 'Standard-Renderer für die normale (XHTML) Wiki-Ausgabe.';
-$lang['renderer__core']        = '%s (DokuWiki Kern)';
-$lang['renderer__plugin']      = '%s (Plugin)';
-$lang['rememberme']            = 'Permanente Login-Cookies erlauben (Auf diesem Computer eingeloggt bleiben)';
-$lang['rss_type']              = 'XML-Feed-Format';
-$lang['rss_linkto']            = 'XML-Feed verlinken auf';
-$lang['rss_content']           = 'Welche Inhalte sollen im XML-Feed dargestellt werden?';
-$lang['rss_update']            = 'XML-Feed Aktualisierungsintervall (Sekunden)';
-$lang['recent_days']           = 'Wie viele letzte Änderungen sollen einsehbar bleiben? (Tage)';
-$lang['rss_show_summary']      = 'Bearbeitungs-Zusammenfassung im XML-Feed anzeigen';
-$lang['rss_media']             = 'Welche Änderungen sollen im XML-Feed angezeigt werden?';
+$lang['cachetime']             = 'Maximale Cachespeicherung (Sekunden)';
 $lang['target____wiki']        = 'Zielfenster für interne Links (target Attribut)';
 $lang['target____interwiki']   = 'Zielfenster für InterWiki-Links (target Attribut)';
 $lang['target____extern']      = 'Zielfenster für Externe Links (target Attribut)';
 $lang['target____media']       = 'Zielfenster für (Bild-)Dateien (target Attribut)';
 $lang['target____windows']     = 'Zielfenster für Windows Freigaben (target Attribut)';
+$lang['mediarevisions']        = 'Media-Revisionen (ältere Versionen) aktivieren?';
+$lang['refcheck']              = 'Auf Verwendung beim Löschen von Media-Dateien testen';
+$lang['gdlib']                 = 'GD Lib Version';
+$lang['im_convert']            = 'Pfad zum ImageMagicks-Konvertierwerkzeug';
+$lang['jpg_quality']           = 'JPEG Kompressionsqualität (0-100)';
+$lang['fetchsize']             = 'Maximale Größe (in Bytes), die fetch.php von extern herunterladen darf';
+$lang['subscribers']           = 'E-Mail-Abos zulassen';
+$lang['subscribe_time']        = 'Zeit nach der Zusammenfassungs- und Änderungslisten-E-Mails verschickt werden; Dieser Wert sollte kleiner als die in recent_days konfigurierte Zeit sein.';
+$lang['notify']                = 'Änderungsmitteilungen an diese E-Mail-Adresse versenden';
+$lang['registernotify']        = 'Information über neu registrierte Benutzer an diese E-Mail-Adresse senden';
+$lang['mailfrom']              = 'Absender-E-Mail-Adresse für automatische Mails';
+$lang['mailprefix']            = 'Präfix für E-Mail-Betreff beim automatischen Versand von Benachrichtigungen';
+$lang['htmlmail']              = 'Versendet optisch angenehmere, aber größere E-Mails im HTML-Format (multipart). Deaktivieren, um Text-Mails zu versenden.';
+$lang['sitemap']               = 'Google Sitemap erzeugen (Tage)';
+$lang['rss_type']              = 'XML-Feed-Format';
+$lang['rss_linkto']            = 'XML-Feed verlinken auf';
+$lang['rss_content']           = 'Welche Inhalte sollen im XML-Feed dargestellt werden?';
+$lang['rss_update']            = 'XML-Feed Aktualisierungsintervall (Sekunden)';
+$lang['rss_show_summary']      = 'Bearbeitungs-Zusammenfassung im XML-Feed anzeigen';
+$lang['rss_media']             = 'Welche Änderungen sollen im XML-Feed angezeigt werden?';
+$lang['updatecheck']           = 'Automatisch auf Updates und Sicherheitswarnungen prüfen? DokuWiki muss sich dafür mit update.dokuwiki.org verbinden.';
+$lang['userewrite']            = 'URL rewriting';
+$lang['useslash']              = 'Schrägstrich (/) als Namensraumtrenner in URLs verwenden';
+$lang['sepchar']               = 'Worttrenner für Seitennamen in URLs';
+$lang['canonical']             = 'Immer Links mit vollständigen URLs erzeugen';
+$lang['fnencode']              = 'Methode um nicht-ASCII Dateinamen zu kodieren.';
+$lang['autoplural']            = 'Bei Links automatisch nach vorhandenen Pluralformen suchen';
+$lang['compression']           = 'Komprimierungsmethode für alte Seitenrevisionen';
+$lang['gzip_output']           = 'Seiten mit gzip komprimiert ausliefern';
+$lang['compress']              = 'JavaScript und Stylesheets komprimieren';
+$lang['cssdatauri']            = 'Größe in Bytes, bis zu der Bilder in CSS-Dateien referenziert werden können, um HTTP-Anfragen zu minimieren. Empfohlene Einstellung: <code>400</code> to <code>600</code> Bytes. Setzen Sie die Einstellung auf <code>0</code> um die Funktion zu deaktivieren.';
+$lang['send404']               = 'Bei nicht vorhandenen Seiten mit 404 Fehlercode antworten';
+$lang['broken_iua']            = 'Falls die Funktion ignore_user_abort auf Ihrem System nicht funktioniert, könnte der Such-Index nicht funktionieren. IIS+PHP/CGI ist bekannt dafür. Siehe auch <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a>.';
+$lang['xsendfile']             = 'Den X-Sendfile-Header nutzen, um Dateien direkt vom Webserver ausliefern zu lassen? Ihr Webserver muss dies unterstützen!';
+$lang['renderer_xhtml']        = 'Standard-Renderer für die normale (XHTML) Wiki-Ausgabe.';
+$lang['renderer__core']        = '%s (DokuWiki Kern)';
+$lang['renderer__plugin']      = '%s (Plugin)';
 $lang['dnslookups']            = 'DokuWiki löst die IP-Adressen von Benutzern zu deren Hostnamen auf. Wenn du einen langsamen, unbrauchbaren DNS-Server verwendest oder die Funktion nicht benötigst, dann sollte diese Option deaktiviert sein.';
 $lang['proxy____host']         = 'Proxy-Server';
 $lang['proxy____port']         = 'Proxy-Port';
@@ -197,6 +199,7 @@ $lang['xsendfile_o_2']         = 'Standard X-Sendfile-Header';
 $lang['xsendfile_o_3']         = 'Proprietärer Nginx X-Accel-Redirect-Header';
 $lang['showuseras_o_loginname'] = 'Login-Name';
 $lang['showuseras_o_username'] = 'Vollständiger Name des Benutzers';
+$lang['showuseras_o_username_link'] = 'Kompletter Name des Benutzers als Interwiki-Link';
 $lang['showuseras_o_email']    = 'E-Mail-Adresse des Benutzers (je nach Mailguard-Einstellung verschleiert)';
 $lang['showuseras_o_email_link'] = 'E-Mail-Adresse des Benutzers als mailto:-Link';
 $lang['useheading_o_0']        = 'Nie';
