@@ -28,8 +28,6 @@ $lang['_links']                = 'Подешавања линковања';
 $lang['_media']                = 'Подешавања медија';
 $lang['_advanced']             = 'Напредна подешавања';
 $lang['_network']              = 'Подешавања мреже';
-$lang['_plugin_sufix']         = 'Подешавања за додатке';
-$lang['_template_sufix']       = 'Подешавања за шаблоне';
 $lang['_msg_setting_undefined'] = 'Нема метаподатака подешавања';
 $lang['_msg_setting_no_class'] = 'Нема класе подешавања';
 $lang['_msg_setting_no_default'] = 'Нема подразумеване вредности';
@@ -50,7 +48,7 @@ $lang['youarehere']            = 'Хиерархијске кораке (стр
 $lang['typography']            = 'Уради типографске замене';
 $lang['htmlok']                = 'Дозволи угњежђени ХТМЛ';
 $lang['phpok']                 = 'Дозволи угњежђени ПХП';
-$lang['dformat']               = 'Облик датума (погледајте ПХПову <a href="http://www.php.net/strftime">strftime</a> функцију)';
+$lang['dformat']               = 'Облик датума (погледајте ПХПову <a href="http://php.net/strftime">strftime</a> функцију)';
 $lang['signature']             = 'Потпис';
 $lang['toptoclevel']           = 'Највиши ниво за садржај';
 $lang['tocminheads']           = 'Минималан број наслова који одређују да ли ће Садржај бити направљен';
@@ -60,7 +58,6 @@ $lang['camelcase']             = 'Користи CamelCase за линкове';
 $lang['deaccent']              = 'Чисти имена страница';
 $lang['useheading']            = 'Преузми наслов првог нивоа за назив странице';
 $lang['refcheck']              = 'Провери референце медијских датотека';
-$lang['refshow']               = 'Број референци које се приказују за медијске датотеке';
 $lang['allowdebug']            = 'Укључи дебаговање <b>искључи ако није потребно!</b>';
 $lang['usewordblock']          = 'Блокирај спам на основу листе речи';
 $lang['indexdelay']            = 'Одлагање индексирања (секунде)';
@@ -84,8 +81,6 @@ $lang['disableactions_other']  = 'Остале наредбе (раздвоје
 $lang['sneaky_index']          = 'По инсталацији DokuWiki ће у индексу приказати све именске просторе. Укључивањем ове опције именски простори у којима корисник нема право читања ће бити сакривени. Консеквенца је да ће и доступни подпростори бити сакривени. Ово доводи до неупотребљивости Права приступа у неким поставкама.';
 $lang['auth_security_timeout'] = 'Временска пауза у аутентификацији (секунде)';
 $lang['securecookie']          = 'Да ли колачићи који су постављени преко ХТТПС треба слати веб читачу само преко ХТТПС? Искључите ову опцију само ако је пријављивање на вики заштићено ССЛом а остали део викија незаштићен.';
-$lang['xmlrpc']                = 'Укључи/искључи ИксМЛ-РПЦ интерфејс';
-$lang['xmlrpcuser']            = 'Ограничи ИксМЛ-РПЦ приступ на наведене групе корисника раздвојене зарезом. Остави празно да би свима дао приступ.';
 $lang['updatecheck']           = 'Провера надоградњи и сигурносних упозорења? Dokuwiki мора да контактира update.dokuwiki.org ради добијања информација.';
 $lang['userewrite']            = 'Направи леп УРЛ';
 $lang['useslash']              = 'Користи косу црту у УРЛу за раздвајање именских простора ';
