@@ -16,6 +16,7 @@
  * @author Peter Åström <eaustreum@gmail.com>
  * @author Håkan Sandell <hakan.sandell@home.se>
  * @author mikael@mallander.net
+ * @author Smorkster Andersson smorkster@gmail.com
  */
 $lang['menu']                  = 'Hantera inställningar';
 $lang['error']                 = 'Inställningarna uppdaterades inte på grund av ett felaktigt värde. Titta igenom dina ändringar och försök sedan spara igen.
@@ -39,32 +40,34 @@ $lang['_anti_spam']            = 'Inställningar för anti-spam';
 $lang['_editing']              = 'Inställningar för redigering';
 $lang['_links']                = 'Inställningar för länkar';
 $lang['_media']                = 'Inställningar för medier';
+$lang['_notifications']        = 'Noterings inställningar';
+$lang['_syndication']          = 'Syndikats inställningar';
 $lang['_advanced']             = 'Avancerade inställningar';
 $lang['_network']              = 'Nätverksinställningar';
-$lang['_plugin_sufix']         = '(inställningar för insticksmodul)';
-$lang['_template_sufix']       = '(inställningar för mall)';
 $lang['_msg_setting_undefined'] = 'Ingen inställningsmetadata.';
 $lang['_msg_setting_no_class'] = 'Ingen inställningsklass.';
 $lang['_msg_setting_no_default'] = 'Inget standardvärde.';
-$lang['fmode']                 = 'Filskydd för nya filer';
-$lang['dmode']                 = 'Filskydd för nya kataloger';
-$lang['lang']                  = 'Språk';
-$lang['basedir']               = 'Grundkatalog';
-$lang['baseurl']               = 'Grund-webbadress';
-$lang['savedir']               = 'Katalog för att spara data';
-$lang['start']                 = 'Startsidans namn';
 $lang['title']                 = 'Wikins namn';
+$lang['start']                 = 'Startsidans namn';
+$lang['lang']                  = 'Språk';
 $lang['template']              = 'Mall';
 $lang['license']               = 'Under vilken licens skall ditt innehåll publiceras?';
-$lang['fullpath']              = 'Visa fullständig sökväg i sidfoten';
+$lang['savedir']               = 'Katalog för att spara data';
+$lang['basedir']               = 'Grundkatalog';
+$lang['baseurl']               = 'Grund-webbadress';
+$lang['cookiedir']             = 'Cookie sökväg. Lämna blankt för att använda basurl.';
+$lang['dmode']                 = 'Filskydd för nya kataloger';
+$lang['fmode']                 = 'Filskydd för nya filer';
+$lang['allowdebug']            = 'Tillåt felsökning <b>stäng av om det inte behövs!</b>';
 $lang['recent']                = 'Antal poster under "Nyligen ändrat"';
+$lang['recent_days']           = 'Hur många ändringar som ska sparas (dagar)';
 $lang['breadcrumbs']           = 'Antal spår';
 $lang['youarehere']            = 'Hierarkiska spår';
+$lang['fullpath']              = 'Visa fullständig sökväg i sidfoten';
 $lang['typography']            = 'Aktivera typografiska ersättningar';
-$lang['htmlok']                = 'Tillåt inbäddad HTML';
-$lang['phpok']                 = 'Tillåt inbäddad PHP';
-$lang['dformat']               = 'Datumformat (se PHP:s <a href="http://www.php.net/strftime">strftime</a>-funktion)';
+$lang['dformat']               = 'Datumformat (se PHP:s <a href="http://php.net/strftime">strftime</a>-funktion)';
 $lang['signature']             = 'Signatur';
+$lang['showuseras']            = 'Vad som skall visas när man visar den användare som senast redigerade en sida';
 $lang['toptoclevel']           = 'Toppnivå för innehållsförteckning';
 $lang['tocminheads']           = 'Minimalt antal rubriker för att avgöra om innehållsförteckning byggs';
 $lang['maxtoclevel']           = 'Maximal nivå för innehållsförteckning';
@@ -72,15 +75,8 @@ $lang['maxseclevel']           = 'Maximal nivå för redigering av rubriker';
 $lang['camelcase']             = 'Använd CamelCase för länkar';
 $lang['deaccent']              = 'Rena sidnamn';
 $lang['useheading']            = 'Använda första rubriken som sidnamn';
-$lang['refcheck']              = 'Kontrollera referenser till mediafiler';
-$lang['refshow']               = 'Antal mediareferenser som ska visas';
-$lang['allowdebug']            = 'Tillåt felsökning <b>stäng av om det inte behövs!</b>';
-$lang['usewordblock']          = 'Blockera spam baserat på ordlista';
-$lang['indexdelay']            = 'Tidsfördröjning före indexering (sek)';
-$lang['relnofollow']           = 'Använd rel="nofollow" för externa länkar';
-$lang['mailguard']             = 'Koda e-postadresser';
-$lang['iexssprotect']          = 'Kontrollera om uppladdade filer innehåller eventuellt skadlig JavaScript eller HTML-kod';
-$lang['showuseras']            = 'Vad som skall visas när man visar den användare som senast redigerade en sida';
+$lang['sneaky_index']          = 'Som standard visar DokuWiki alla namnrymder på indexsidan. Genom att aktivera det här valet döljer man namnrymder som användaren inte har behörighet att läsa. Det kan leda till att man döljer åtkomliga undernamnrymder, och gör indexet oanvändbart med vissa ACL-inställningar.';
+$lang['hidepages']             = 'Dölj matchande sidor (reguljära uttryck)';
 $lang['useacl']                = 'Använd behörighetslista (ACL)';
 $lang['autopasswd']            = 'Autogenerera lösenord';
 $lang['authtype']              = 'System för autentisering';
@@ -89,60 +85,68 @@ $lang['defaultgroup']          = 'Förvald grupp';
 $lang['superuser']             = 'Huvudadministratör - en grupp eller en användare med full tillgång till alla sidor och funktioner, oavsett behörighetsinställningars';
 $lang['manager']               = 'Administratör -- en grupp eller användare med tillgång till vissa administrativa funktioner.';
 $lang['profileconfirm']        = 'Bekräfta ändringarna i profilen med lösenordet';
+$lang['rememberme']            = 'Tillåt permanenta inloggningscookies (kom ihåg mig)';
 $lang['disableactions']        = 'Stäng av funktioner i DokuWiki';
 $lang['disableactions_check']  = 'Kontroll';
 $lang['disableactions_subscription'] = 'Prenumerera/Säg upp prenumeration';
 $lang['disableactions_wikicode'] = 'Visa källkod/Exportera råtext';
 $lang['disableactions_other']  = 'Andra funktioner (kommaseparerade)';
-$lang['sneaky_index']          = 'Som standard visar DokuWiki alla namnrymder på indexsidan. Genom att aktivera det här valet döljer man namnrymder som användaren inte har behörighet att läsa. Det kan leda till att man döljer åtkomliga undernamnrymder, och gör indexet oanvändbart med vissa ACL-inställningar.';
 $lang['auth_security_timeout'] = 'Autentisieringssäkerhets timeout (sekunder)';
 $lang['securecookie']          = 'Skall cookies som sätts via HTTPS endast skickas via HTTPS från webbläsaren? Avaktivera detta alternativ endast om inloggningen till din wiki är säkrad med SSL men läsning av wikin är osäkrad.';
-$lang['updatecheck']           = 'Kontrollera uppdateringar och säkerhetsvarningar? DokuWiki behöver kontakta update.dokuwiki.org för den här funktionen.';
-$lang['userewrite']            = 'Använd rena webbadresser';
-$lang['useslash']              = 'Använd snedstreck för att separera namnrymder i webbadresser';
+$lang['usewordblock']          = 'Blockera spam baserat på ordlista';
+$lang['relnofollow']           = 'Använd rel="nofollow" för externa länkar';
+$lang['indexdelay']            = 'Tidsfördröjning före indexering (sek)';
+$lang['mailguard']             = 'Koda e-postadresser';
+$lang['iexssprotect']          = 'Kontrollera om uppladdade filer innehåller eventuellt skadlig JavaScript eller HTML-kod';
 $lang['usedraft']              = 'Spara utkast automatiskt under redigering';
-$lang['sepchar']               = 'Ersätt blanktecken i webbadresser med';
-$lang['canonical']             = 'Använd fullständiga webbadresser';
-$lang['autoplural']            = 'Leta efter pluralformer av länkar';
-$lang['compression']           = 'Metod för komprimering av gamla versioner';
-$lang['cachetime']             = 'Maximal livslängd för cache (sek)';
+$lang['htmlok']                = 'Tillåt inbäddad HTML';
+$lang['phpok']                 = 'Tillåt inbäddad PHP';
 $lang['locktime']              = 'Maximal livslängd för fillåsning (sek)';
-$lang['fetchsize']             = 'Maximal storlek (bytes) som fetch.php får ladda ned  externt';
-$lang['notify']                = 'Skicka meddelande om ändrade sidor till den här e-postadressen';
-$lang['registernotify']        = 'Skicka meddelande om nyregistrerade användare till en här e-postadressen';
-$lang['mailfrom']              = 'Avsändaradress i automatiska e-postmeddelanden';
-$lang['mailprefix']            = 'Prefix i början på ämnesraden vid automatiska e-postmeddelanden';
-$lang['gzip_output']           = 'Använd gzip Content-Encoding för xhtml';
-$lang['gdlib']                 = 'Version av GD-biblioteket';
-$lang['im_convert']            = 'Sökväg till ImageMagicks konverteringsverktyg';
-$lang['jpg_quality']           = 'Kvalitet för JPG-komprimering (0-100)';
-$lang['subscribers']           = 'Aktivera stöd för prenumeration på ändringar';
-$lang['compress']              = 'Komprimera CSS och javascript';
-$lang['hidepages']             = 'Dölj matchande sidor (reguljära uttryck)';
-$lang['send404']               = 'Skicka "HTTP 404/Page Not Found" för sidor som inte finns';
-$lang['sitemap']               = 'Skapa Google sitemap (dagar)';
-$lang['broken_iua']            = 'Är funktionen ignore_user_abort trasig på ditt system? Det kan i så fall leda till att indexering av sökningar inte fungerar. Detta är ett känt problem med IIS+PHP/CGI. Se <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a> för mer info.';
-$lang['xsendfile']             = 'Använd X-Sendfile huvudet för att låta webservern leverera statiska filer? Din webserver behöver stöd för detta.';
-$lang['renderer_xhtml']        = 'Generera för användning i huvudwikipresentation (xhtml)';
-$lang['renderer__core']        = '%s (dokuwiki core)';
-$lang['renderer__plugin']      = '%s (plugin)';
-$lang['rememberme']            = 'Tillåt permanenta inloggningscookies (kom ihåg mig)';
-$lang['rss_type']              = 'Typ av XML-flöde';
-$lang['rss_linkto']            = 'XML-flöde pekar på';
-$lang['rss_content']           = 'Vad ska visas för saker i XML-flödet?';
-$lang['rss_update']            = 'Uppdateringsintervall för XML-flöde (sek)';
-$lang['recent_days']           = 'Hur många ändringar som ska sparas (dagar)';
-$lang['rss_show_summary']      = 'XML-flöde visar sammanfattning i rubriken';
+$lang['cachetime']             = 'Maximal livslängd för cache (sek)';
 $lang['target____wiki']        = 'Målfönster för interna länkar';
 $lang['target____interwiki']   = 'Målfönster för interwiki-länkar';
 $lang['target____extern']      = 'Målfönster för externa länkar';
 $lang['target____media']       = 'Målfönster för medialänkar';
 $lang['target____windows']     = 'Målfönster för windowslänkar';
+$lang['refcheck']              = 'Kontrollera referenser till mediafiler';
+$lang['gdlib']                 = 'Version av GD-biblioteket';
+$lang['im_convert']            = 'Sökväg till ImageMagicks konverteringsverktyg';
+$lang['jpg_quality']           = 'Kvalitet för JPG-komprimering (0-100)';
+$lang['fetchsize']             = 'Maximal storlek (bytes) som fetch.php får ladda ned  externt';
+$lang['subscribers']           = 'Aktivera stöd för prenumeration på ändringar';
+$lang['notify']                = 'Skicka meddelande om ändrade sidor till den här e-postadressen';
+$lang['registernotify']        = 'Skicka meddelande om nyregistrerade användare till en här e-postadressen';
+$lang['mailfrom']              = 'Avsändaradress i automatiska e-postmeddelanden';
+$lang['mailprefix']            = 'Prefix i början på ämnesraden vid automatiska e-postmeddelanden';
+$lang['sitemap']               = 'Skapa Google sitemap (dagar)';
+$lang['rss_type']              = 'Typ av XML-flöde';
+$lang['rss_linkto']            = 'XML-flöde pekar på';
+$lang['rss_content']           = 'Vad ska visas för saker i XML-flödet?';
+$lang['rss_update']            = 'Uppdateringsintervall för XML-flöde (sek)';
+$lang['rss_show_summary']      = 'XML-flöde visar sammanfattning i rubriken';
+$lang['rss_media']             = 'Vilka ändringar ska listas i XML flödet?';
+$lang['updatecheck']           = 'Kontrollera uppdateringar och säkerhetsvarningar? DokuWiki behöver kontakta update.dokuwiki.org för den här funktionen.';
+$lang['userewrite']            = 'Använd rena webbadresser';
+$lang['useslash']              = 'Använd snedstreck för att separera namnrymder i webbadresser';
+$lang['sepchar']               = 'Ersätt blanktecken i webbadresser med';
+$lang['canonical']             = 'Använd fullständiga webbadresser';
+$lang['fnencode']              = 'Metod för kodning av icke-ASCII filnamn.';
+$lang['autoplural']            = 'Leta efter pluralformer av länkar';
+$lang['compression']           = 'Metod för komprimering av gamla versioner';
+$lang['gzip_output']           = 'Använd gzip Content-Encoding för xhtml';
+$lang['compress']              = 'Komprimera CSS och javascript';
+$lang['send404']               = 'Skicka "HTTP 404/Page Not Found" för sidor som inte finns';
+$lang['broken_iua']            = 'Är funktionen ignore_user_abort trasig på ditt system? Det kan i så fall leda till att indexering av sökningar inte fungerar. Detta är ett känt problem med IIS+PHP/CGI. Se <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a> för mer info.';
+$lang['xsendfile']             = 'Använd X-Sendfile huvudet för att låta webservern leverera statiska filer? Din webserver behöver stöd för detta.';
+$lang['renderer_xhtml']        = 'Generera för användning i huvudwikipresentation (xhtml)';
+$lang['renderer__core']        = '%s (dokuwiki core)';
+$lang['renderer__plugin']      = '%s (plugin)';
 $lang['proxy____host']         = 'Proxyserver';
 $lang['proxy____port']         = 'Proxyport';
 $lang['proxy____user']         = 'Användarnamn för proxy';
 $lang['proxy____pass']         = 'Lösenord för proxy';
 $lang['proxy____ssl']          = 'Använd ssl för anslutning till proxy';
+$lang['proxy____except']       = 'Regular expression för matchning av URL som proxy ska hoppa över.';
 $lang['safemodehack']          = 'Aktivera safemode hack';
 $lang['ftp____host']           = 'FTP-server för safemode hack';
 $lang['ftp____port']           = 'FTP-port för safemode hack';
@@ -190,3 +194,4 @@ $lang['useheading_o_0']        = 'Aldrig';
 $lang['useheading_o_navigation'] = 'Endst navigering';
 $lang['useheading_o_content']  = 'Endast innehåll i wiki';
 $lang['useheading_o_1']        = 'Alltid';
+$lang['readdircache']          = 'Max ålder för readdir cache (sek)';
