@@ -1,20 +1,19 @@
 <?php
+
 /**
- * Esperanto language file
- *
+ * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Felipo Kastro <fefcas@gmail.com>
  * @author Felipe Castro <fefcas@gmail.com>
  * @author Robert Bogenschneider <robog@gmx.de>
  * @author Erik Pedersen <erik pedersen@shaw.ca>
  * @author Erik Pedersen <erik.pedersen@shaw.ca>
- * @author Robert Bogenschneider <robog@GMX.de>
- * @author Robert BOGENSCHNEIDER <robog@gmx.de>
- * @author Robert BOGENSCHNEIDER <bogi@UEA.org>
+ * @author Robert Bogenschneider <bogi@uea.org>
  */
 $lang['name']                  = 'Populareca enketo (eble la ŝargo prokrastos iomete)';
 $lang['submit']                = 'Sendi datumaron';
 $lang['autosubmit']            = 'Aŭtomate sendi datumaron monate';
-$lang['submissionFailed']      = 'La datumaro ne povis esti sendata pro la jena eraro:';
+$lang['submissionFailed']      = 'La datumaro ne povis esti sendata tial:';
 $lang['submitDirectly']        = 'Vi povas sendi vi mem la datumaron per la sekva informilo.';
-$lang['autosubmitError']       = 'La lasta aŭtomata sendo malsukcesis, pro la jena eraro:';
-$lang['lastSent']              = 'La datumaro estas sendita';
+$lang['autosubmitError']       = 'La lasta aŭtomata sendo malsukcesis, tial:';
+$lang['lastSent']              = 'La datumaro sendiĝis';
